#This file was originally generated by PyScripter's unitest wizard

from builtins import str, int
import unittest
from .. import ftd2xx
from ..ftd2xx import _ft

class TestDeviceError(unittest.TestCase):

    def setUp(self):
        self.expt = ftd2xx.DeviceError(0)

    def tearDown(self):
        pass

    def test__str__(self):
        self.assertTrue(str(self.expt) == 'OK')

class TestFTD2XX(unittest.TestCase):

    def setUp(self):
        self.device = ftd2xx.open()

    def tearDown(self):
        self.device.close()

    def testclose(self):
        pass

    def testread(self):
        self.device.setTimeouts(1000, 0)
        self.assertTrue(isinstance(self.device.read(1), bytes))

    def testwrite(self):
        self.assertTrue(isinstance(self.device.write(b'%c' % 0x0), int))

    def testioctl(self):
        pass

    def testsetBaudRate(self):
        pass

    def testsetDivisor(self):
        pass

    def testsetDataCharacteristics(self):
        pass

    def testsetFlowControl(self):
        pass

    def testresetDevice(self):
        pass

    def testsetDtr(self):
        pass

    def testclrDtr(self):
        pass

    def testsetRts(self):
        pass

    def testclrRts(self):
        pass

    def testgetModemStatus(self):
        pass

    def testsetChars(self):
        pass

    def testpurge(self):
        pass

    def testsetTimeouts(self):
        pass

    def testsetDeadmanTimeout(self):
        pass

    def testgetQueueStatus(self):
        self.assertTrue(isinstance(self.device.getQueueStatus(), int))

    def testsetEventNotification(self):
        pass

    def testgetStatus(self):
        self.assertTrue(isinstance(self.device.getStatus(), tuple))

    def testsetBreakOn(self):
        pass

    def testsetBreakOff(self):
        pass

    def testsetWaitMask(self):
        pass

    def testwaitOnMask(self):
        pass

    def testgetEventStatus(self):
        pass

    def testsetLatencyTimer(self):
        pass

    def testgetLatencyTimer(self):
        self.assertTrue(isinstance(self.device.getLatencyTimer(), int))

    def testsetBitMode(self):
        pass

    def testgetBitMode(self):
        self.assertTrue(isinstance(self.device.getBitMode(), int))

    def testsetUSBParameters(self):
        pass

    def testgetDeviceInfo(self):
        self.assertTrue(isinstance(self.device.getDeviceInfo(), dict))

    def teststopInTask(self):
        pass

    def testrestartInTask(self):
        pass

    def testsetRestPipeRetryCount(self):
        pass

    def testresetPort(self):
        pass

    def testcyclePort(self):
        pass

    def testgetDriverVersion(self):
        self.assertTrue(isinstance(self.device.getDriverVersion(), int))

    def testeeProgram(self):
        pass

    def testeeRead(self):
        self.assertTrue(isinstance(self.device.eeRead(), ftd2xx._ft.ft_program_data))

    def testeeUASize(self):
        self.assertTrue(isinstance(self.device.eeUASize(), int))

    def testeeUAWrite(self):
        pass

    def testeeUARead(self):
        self.assertTrue(isinstance(self.device.eeUARead(5), bytes))

class TestGlobalFunctions(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testcall_ft(self):
        pass

    def testlistDevices(self):
        self.assertTrue(isinstance(ftd2xx.listDevices(), list))

    def testgetLibraryVersion(self):
        self.assertTrue(isinstance(ftd2xx.getLibraryVersion(), int))

    def testcreateDeviceInfoList(self):
        self.assertTrue(isinstance(ftd2xx.createDeviceInfoList(), int))

    def testgetDeviceInfoDetail(self):
        self.assertTrue(isinstance(ftd2xx.getDeviceInfoDetail(), dict))

    def testopen(self):
        try:
            device = ftd2xx.open()
            self.assertTrue(isinstance(device, ftd2xx.FTD2XX))
        except AssertionError:
            raise
        else:
            device.close()

    def testopenEx(self):
        try:
            dev0_id = ftd2xx.listDevices()[0]
            dev0 = ftd2xx.openEx(dev0_id)
            self.assertTrue(isinstance(dev0, ftd2xx.FTD2XX))
        except AssertionError:
            raise
        else:
            dev0.close()

    def testw32CreateFile(self):
        pass

    def testgetVIDPID(self):
        pass

    def testsetVIDPID(self):
        pass

if __name__ == '__main__':
    unittest.main()



# generated by 'xml2py'
# flags '-kdefst -d -c -o _ftd2xx_osx.py ftd2xx.xml -l ftd2xx'
from ctypes import *

STRING = c_char_p
_libraries = {}
_libraries['/usr/local/lib/libftd2xx.dylib'] = CDLL('/usr/local/lib/libftd2xx.dylib')


FT_IO_ERROR = 4
FT_INVALID_BAUD_RATE = 7
FT_DEVICE_100AX = 2
FT_DEVICE_NOT_OPENED_FOR_WRITE = 9
FT_DEVICE_BM = 0
FT_EEPROM_ERASE_FAILED = 13
FT_EEPROM_NOT_PROGRAMMED = 15
FT_FAILED_TO_WRITE_DEVICE = 10
FT_DEVICE_232R = 5
FT_EEPROM_WRITE_FAILED = 12
FT_NOT_SUPPORTED = 17
FT_INVALID_PARAMETER = 6
FT_DEVICE_UNKNOWN = 3
FT_INSUFFICIENT_RESOURCES = 5
FT_DEVICE_AM = 1
FT_DEVICE_NOT_OPENED = 3
FT_INVALID_HANDLE = 1
FT_EEPROM_NOT_PRESENT = 14
FT_DEVICE_NOT_OPENED_FOR_ERASE = 8
FT_OTHER_ERROR = 18
FT_OK = 0
FT_DEVICE_NOT_FOUND = 2
FT_INVALID_ARGS = 16
FT_DEVICE_2232C = 4
FT_EEPROM_READ_FAILED = 11
__darwin_nl_item = c_int
__darwin_wctrans_t = c_int
__darwin_wctype_t = c_ulong
__int8_t = c_byte
__uint8_t = c_ubyte
__int16_t = c_short
__uint16_t = c_ushort
__int32_t = c_int
__uint32_t = c_uint
__int64_t = c_longlong
__uint64_t = c_ulonglong
__darwin_intptr_t = c_long
__darwin_natural_t = c_uint
__darwin_ct_rune_t = c_int
# /usr/include/i386/_types.h 79
class __mbstate_t(Union):
    pass
__darwin_mbstate_t = __mbstate_t
__darwin_ptrdiff_t = c_int
__darwin_size_t = c_ulong
__darwin_va_list = STRING
__darwin_wchar_t = c_int
__darwin_rune_t = __darwin_wchar_t
__darwin_wint_t = c_int
__darwin_clock_t = c_ulong
__darwin_socklen_t = __uint32_t
__darwin_ssize_t = c_long
__darwin_time_t = c_long
# /usr/include/sys/_types.h 64
class _opaque_pthread_attr_t(Structure):
    pass
__darwin_pthread_attr_t = _opaque_pthread_attr_t
pthread_attr_t = __darwin_pthread_attr_t
# /usr/include/sys/_types.h 65
class _opaque_pthread_cond_t(Structure):
    pass
__darwin_pthread_cond_t = _opaque_pthread_cond_t
pthread_cond_t = __darwin_pthread_cond_t
# /usr/include/sys/_types.h 66
class _opaque_pthread_condattr_t(Structure):
    pass
__darwin_pthread_condattr_t = _opaque_pthread_condattr_t
pthread_condattr_t = __darwin_pthread_condattr_t
__darwin_pthread_key_t = c_ulong
pthread_key_t = __darwin_pthread_key_t
# /usr/include/sys/_types.h 67
class _opaque_pthread_mutex_t(Structure):
    pass
__darwin_pthread_mutex_t = _opaque_pthread_mutex_t
pthread_mutex_t = __darwin_pthread_mutex_t
# /usr/include/sys/_types.h 68
class _opaque_pthread_mutexattr_t(Structure):
    pass
__darwin_pthread_mutexattr_t = _opaque_pthread_mutexattr_t
pthread_mutexattr_t = __darwin_pthread_mutexattr_t
# /usr/include/sys/_types.h 69
class _opaque_pthread_once_t(Structure):
    pass
__darwin_pthread_once_t = _opaque_pthread_once_t
pthread_once_t = __darwin_pthread_once_t
# /usr/include/sys/_types.h 70
class _opaque_pthread_rwlock_t(Structure):
    pass
__darwin_pthread_rwlock_t = _opaque_pthread_rwlock_t
pthread_rwlock_t = __darwin_pthread_rwlock_t
# /usr/include/sys/_types.h 71
class _opaque_pthread_rwlockattr_t(Structure):
    pass
__darwin_pthread_rwlockattr_t = _opaque_pthread_rwlockattr_t
pthread_rwlockattr_t = __darwin_pthread_rwlockattr_t
# /usr/include/sys/_types.h 72
class _opaque_pthread_t(Structure):
    pass
__darwin_pthread_t = POINTER(_opaque_pthread_t)
pthread_t = __darwin_pthread_t
__darwin_mach_port_name_t = __darwin_natural_t
__darwin_mach_port_t = __darwin_mach_port_name_t
mach_port_t = __darwin_mach_port_t
__darwin_sigset_t = __uint32_t
sigset_t = __darwin_sigset_t
# /usr/include/pthread.h 245
pthread_atfork = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_atfork
pthread_atfork.restype = c_int
# pthread_atfork(p1, p2, p3)
pthread_atfork.argtypes = [CFUNCTYPE(None), CFUNCTYPE(None), CFUNCTYPE(None)]
pthread_atfork.__doc__ = \
"""int pthread_atfork(unknown * p1, unknown * p2, unknown * p3)
/usr/include/pthread.h:245"""
# /usr/include/pthread.h 246
pthread_attr_destroy = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_destroy
pthread_attr_destroy.restype = c_int
# pthread_attr_destroy(p1)
pthread_attr_destroy.argtypes = [POINTER(pthread_attr_t)]
pthread_attr_destroy.__doc__ = \
"""int pthread_attr_destroy(pthread_attr_t * p1)
/usr/include/pthread.h:246"""
# /usr/include/pthread.h 248
pthread_attr_getdetachstate = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_getdetachstate
pthread_attr_getdetachstate.restype = c_int
# pthread_attr_getdetachstate(p1, p2)
pthread_attr_getdetachstate.argtypes = [POINTER(pthread_attr_t), POINTER(c_int)]
pthread_attr_getdetachstate.__doc__ = \
"""int pthread_attr_getdetachstate(unknown * p1, int * p2)
/usr/include/pthread.h:248"""
size_t = __darwin_size_t
# /usr/include/pthread.h 250
pthread_attr_getguardsize = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_getguardsize
pthread_attr_getguardsize.restype = c_int
# pthread_attr_getguardsize(p1, p2)
pthread_attr_getguardsize.argtypes = [POINTER(pthread_attr_t), POINTER(size_t)]
pthread_attr_getguardsize.__doc__ = \
"""int pthread_attr_getguardsize(unknown * p1, size_t * p2)
/usr/include/pthread.h:250"""
# /usr/include/pthread.h 252
pthread_attr_getinheritsched = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_getinheritsched
pthread_attr_getinheritsched.restype = c_int
# pthread_attr_getinheritsched(p1, p2)
pthread_attr_getinheritsched.argtypes = [POINTER(pthread_attr_t), POINTER(c_int)]
pthread_attr_getinheritsched.__doc__ = \
"""int pthread_attr_getinheritsched(unknown * p1, int * p2)
/usr/include/pthread.h:252"""
# /usr/include/sched.h 35
class sched_param(Structure):
    pass
# /usr/include/pthread.h 254
pthread_attr_getschedparam = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_getschedparam
pthread_attr_getschedparam.restype = c_int
# pthread_attr_getschedparam(p1, p2)
pthread_attr_getschedparam.argtypes = [POINTER(pthread_attr_t), POINTER(sched_param)]
pthread_attr_getschedparam.__doc__ = \
"""int pthread_attr_getschedparam(unknown * p1, sched_param * p2)
/usr/include/pthread.h:254"""
# /usr/include/pthread.h 256
pthread_attr_getschedpolicy = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_getschedpolicy
pthread_attr_getschedpolicy.restype = c_int
# pthread_attr_getschedpolicy(p1, p2)
pthread_attr_getschedpolicy.argtypes = [POINTER(pthread_attr_t), POINTER(c_int)]
pthread_attr_getschedpolicy.__doc__ = \
"""int pthread_attr_getschedpolicy(unknown * p1, int * p2)
/usr/include/pthread.h:256"""
# /usr/include/pthread.h 257
pthread_attr_getscope = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_getscope
pthread_attr_getscope.restype = c_int
# pthread_attr_getscope(p1, p2)
pthread_attr_getscope.argtypes = [POINTER(pthread_attr_t), POINTER(c_int)]
pthread_attr_getscope.__doc__ = \
"""int pthread_attr_getscope(unknown * p1, int * p2)
/usr/include/pthread.h:257"""
# /usr/include/pthread.h 259
pthread_attr_getstack = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_getstack
pthread_attr_getstack.restype = c_int
# pthread_attr_getstack(p1, p2, p3)
pthread_attr_getstack.argtypes = [POINTER(pthread_attr_t), POINTER(c_void_p), POINTER(size_t)]
pthread_attr_getstack.__doc__ = \
"""int pthread_attr_getstack(unknown * p1, void * * p2, size_t * p3)
/usr/include/pthread.h:259"""
# /usr/include/pthread.h 261
pthread_attr_getstackaddr = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_getstackaddr
pthread_attr_getstackaddr.restype = c_int
# pthread_attr_getstackaddr(p1, p2)
pthread_attr_getstackaddr.argtypes = [POINTER(pthread_attr_t), POINTER(c_void_p)]
pthread_attr_getstackaddr.__doc__ = \
"""int pthread_attr_getstackaddr(unknown * p1, void * * p2)
/usr/include/pthread.h:261"""
# /usr/include/pthread.h 263
pthread_attr_getstacksize = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_getstacksize
pthread_attr_getstacksize.restype = c_int
# pthread_attr_getstacksize(p1, p2)
pthread_attr_getstacksize.argtypes = [POINTER(pthread_attr_t), POINTER(size_t)]
pthread_attr_getstacksize.__doc__ = \
"""int pthread_attr_getstacksize(unknown * p1, size_t * p2)
/usr/include/pthread.h:263"""
# /usr/include/pthread.h 264
pthread_attr_init = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_init
pthread_attr_init.restype = c_int
# pthread_attr_init(p1)
pthread_attr_init.argtypes = [POINTER(pthread_attr_t)]
pthread_attr_init.__doc__ = \
"""int pthread_attr_init(pthread_attr_t * p1)
/usr/include/pthread.h:264"""
# /usr/include/pthread.h 266
pthread_attr_setdetachstate = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_setdetachstate
pthread_attr_setdetachstate.restype = c_int
# pthread_attr_setdetachstate(p1, p2)
pthread_attr_setdetachstate.argtypes = [POINTER(pthread_attr_t), c_int]
pthread_attr_setdetachstate.__doc__ = \
"""int pthread_attr_setdetachstate(pthread_attr_t * p1, int p2)
/usr/include/pthread.h:266"""
# /usr/include/pthread.h 267
pthread_attr_setguardsize = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_setguardsize
pthread_attr_setguardsize.restype = c_int
# pthread_attr_setguardsize(p1, p2)
pthread_attr_setguardsize.argtypes = [POINTER(pthread_attr_t), size_t]
pthread_attr_setguardsize.__doc__ = \
"""int pthread_attr_setguardsize(pthread_attr_t * p1, size_t p2)
/usr/include/pthread.h:267"""
# /usr/include/pthread.h 269
pthread_attr_setinheritsched = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_setinheritsched
pthread_attr_setinheritsched.restype = c_int
# pthread_attr_setinheritsched(p1, p2)
pthread_attr_setinheritsched.argtypes = [POINTER(pthread_attr_t), c_int]
pthread_attr_setinheritsched.__doc__ = \
"""int pthread_attr_setinheritsched(pthread_attr_t * p1, int p2)
/usr/include/pthread.h:269"""
sched_param._fields_ = [
    # /usr/include/sched.h 35
    ('sched_priority', c_int),
    ('__opaque', c_char * 4),
]
# /usr/include/pthread.h 271
pthread_attr_setschedparam = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_setschedparam
pthread_attr_setschedparam.restype = c_int
# pthread_attr_setschedparam(p1, p2)
pthread_attr_setschedparam.argtypes = [POINTER(pthread_attr_t), POINTER(sched_param)]
pthread_attr_setschedparam.__doc__ = \
"""int pthread_attr_setschedparam(pthread_attr_t * p1, unknown * p2)
/usr/include/pthread.h:271"""
# /usr/include/pthread.h 273
pthread_attr_setschedpolicy = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_setschedpolicy
pthread_attr_setschedpolicy.restype = c_int
# pthread_attr_setschedpolicy(p1, p2)
pthread_attr_setschedpolicy.argtypes = [POINTER(pthread_attr_t), c_int]
pthread_attr_setschedpolicy.__doc__ = \
"""int pthread_attr_setschedpolicy(pthread_attr_t * p1, int p2)
/usr/include/pthread.h:273"""
# /usr/include/pthread.h 274
pthread_attr_setscope = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_setscope
pthread_attr_setscope.restype = c_int
# pthread_attr_setscope(p1, p2)
pthread_attr_setscope.argtypes = [POINTER(pthread_attr_t), c_int]
pthread_attr_setscope.__doc__ = \
"""int pthread_attr_setscope(pthread_attr_t * p1, int p2)
/usr/include/pthread.h:274"""
# /usr/include/pthread.h 276
pthread_attr_setstack = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_setstack
pthread_attr_setstack.restype = c_int
# pthread_attr_setstack(p1, p2, p3)
pthread_attr_setstack.argtypes = [POINTER(pthread_attr_t), c_void_p, size_t]
pthread_attr_setstack.__doc__ = \
"""int pthread_attr_setstack(pthread_attr_t * p1, void * p2, size_t p3)
/usr/include/pthread.h:276"""
# /usr/include/pthread.h 278
pthread_attr_setstackaddr = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_setstackaddr
pthread_attr_setstackaddr.restype = c_int
# pthread_attr_setstackaddr(p1, p2)
pthread_attr_setstackaddr.argtypes = [POINTER(pthread_attr_t), c_void_p]
pthread_attr_setstackaddr.__doc__ = \
"""int pthread_attr_setstackaddr(pthread_attr_t * p1, void * p2)
/usr/include/pthread.h:278"""
# /usr/include/pthread.h 279
pthread_attr_setstacksize = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_attr_setstacksize
pthread_attr_setstacksize.restype = c_int
# pthread_attr_setstacksize(p1, p2)
pthread_attr_setstacksize.argtypes = [POINTER(pthread_attr_t), size_t]
pthread_attr_setstacksize.__doc__ = \
"""int pthread_attr_setstacksize(pthread_attr_t * p1, size_t p2)
/usr/include/pthread.h:279"""
# /usr/include/pthread.h 280
pthread_cancel = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_cancel
pthread_cancel.restype = c_int
# pthread_cancel(p1)
pthread_cancel.argtypes = [pthread_t]
pthread_cancel.__doc__ = \
"""int pthread_cancel(pthread_t p1)
/usr/include/pthread.h:280"""
# /usr/include/pthread.h 282
pthread_cond_broadcast = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_cond_broadcast
pthread_cond_broadcast.restype = c_int
# pthread_cond_broadcast(p1)
pthread_cond_broadcast.argtypes = [POINTER(pthread_cond_t)]
pthread_cond_broadcast.__doc__ = \
"""int pthread_cond_broadcast(pthread_cond_t * p1)
/usr/include/pthread.h:282"""
# /usr/include/pthread.h 283
pthread_cond_destroy = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_cond_destroy
pthread_cond_destroy.restype = c_int
# pthread_cond_destroy(p1)
pthread_cond_destroy.argtypes = [POINTER(pthread_cond_t)]
pthread_cond_destroy.__doc__ = \
"""int pthread_cond_destroy(pthread_cond_t * p1)
/usr/include/pthread.h:283"""
# /usr/include/pthread.h 285
pthread_cond_init = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_cond_init
pthread_cond_init.restype = c_int
# pthread_cond_init(p1, p2)
pthread_cond_init.argtypes = [POINTER(pthread_cond_t), POINTER(pthread_condattr_t)]
pthread_cond_init.__doc__ = \
"""int pthread_cond_init(pthread_cond_t * p1, unknown * p2)
/usr/include/pthread.h:285"""
# /usr/include/pthread.h 286
pthread_cond_signal = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_cond_signal
pthread_cond_signal.restype = c_int
# pthread_cond_signal(p1)
pthread_cond_signal.argtypes = [POINTER(pthread_cond_t)]
pthread_cond_signal.__doc__ = \
"""int pthread_cond_signal(pthread_cond_t * p1)
/usr/include/pthread.h:286"""
# /usr/include/sys/_structs.h 89
class timespec(Structure):
    pass
timespec._fields_ = [
    # /usr/include/sys/_structs.h 89
    ('tv_sec', __darwin_time_t),
    ('tv_nsec', c_long),
]
# /usr/include/pthread.h 289
pthread_cond_timedwait = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_cond_timedwait
pthread_cond_timedwait.restype = c_int
# pthread_cond_timedwait(p1, p2, p3)
pthread_cond_timedwait.argtypes = [POINTER(pthread_cond_t), POINTER(pthread_mutex_t), POINTER(timespec)]
pthread_cond_timedwait.__doc__ = \
"""int pthread_cond_timedwait(pthread_cond_t * p1, pthread_mutex_t * p2, unknown * p3)
/usr/include/pthread.h:289"""
# /usr/include/pthread.h 291
pthread_cond_wait = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_cond_wait
pthread_cond_wait.restype = c_int
# pthread_cond_wait(p1, p2)
pthread_cond_wait.argtypes = [POINTER(pthread_cond_t), POINTER(pthread_mutex_t)]
pthread_cond_wait.__doc__ = \
"""int pthread_cond_wait(pthread_cond_t * p1, pthread_mutex_t * p2)
/usr/include/pthread.h:291"""
# /usr/include/pthread.h 292
pthread_condattr_destroy = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_condattr_destroy
pthread_condattr_destroy.restype = c_int
# pthread_condattr_destroy(p1)
pthread_condattr_destroy.argtypes = [POINTER(pthread_condattr_t)]
pthread_condattr_destroy.__doc__ = \
"""int pthread_condattr_destroy(pthread_condattr_t * p1)
/usr/include/pthread.h:292"""
# /usr/include/pthread.h 293
pthread_condattr_init = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_condattr_init
pthread_condattr_init.restype = c_int
# pthread_condattr_init(p1)
pthread_condattr_init.argtypes = [POINTER(pthread_condattr_t)]
pthread_condattr_init.__doc__ = \
"""int pthread_condattr_init(pthread_condattr_t * p1)
/usr/include/pthread.h:293"""
# /usr/include/pthread.h 295
pthread_condattr_getpshared = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_condattr_getpshared
pthread_condattr_getpshared.restype = c_int
# pthread_condattr_getpshared(p1, p2)
pthread_condattr_getpshared.argtypes = [POINTER(pthread_condattr_t), POINTER(c_int)]
pthread_condattr_getpshared.__doc__ = \
"""int pthread_condattr_getpshared(unknown * p1, int * p2)
/usr/include/pthread.h:295"""
# /usr/include/pthread.h 297
pthread_condattr_setpshared = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_condattr_setpshared
pthread_condattr_setpshared.restype = c_int
# pthread_condattr_setpshared(p1, p2)
pthread_condattr_setpshared.argtypes = [POINTER(pthread_condattr_t), c_int]
pthread_condattr_setpshared.__doc__ = \
"""int pthread_condattr_setpshared(pthread_condattr_t * p1, int p2)
/usr/include/pthread.h:297"""
# /usr/include/pthread.h 301
pthread_create = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_create
pthread_create.restype = c_int
# pthread_create(p1, p2, p3, p4)
pthread_create.argtypes = [POINTER(pthread_t), POINTER(pthread_attr_t), CFUNCTYPE(c_void_p, c_void_p), c_void_p]
pthread_create.__doc__ = \
"""int pthread_create(pthread_t * p1, unknown * p2, unknown * p3, void * p4)
/usr/include/pthread.h:301"""
# /usr/include/pthread.h 302
pthread_detach = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_detach
pthread_detach.restype = c_int
# pthread_detach(p1)
pthread_detach.argtypes = [pthread_t]
pthread_detach.__doc__ = \
"""int pthread_detach(pthread_t p1)
/usr/include/pthread.h:302"""
# /usr/include/pthread.h 304
pthread_equal = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_equal
pthread_equal.restype = c_int
# pthread_equal(p1, p2)
pthread_equal.argtypes = [pthread_t, pthread_t]
pthread_equal.__doc__ = \
"""int pthread_equal(pthread_t p1, pthread_t p2)
/usr/include/pthread.h:304"""
# /usr/include/pthread.h 305
pthread_exit = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_exit
pthread_exit.restype = None
# pthread_exit(p1)
pthread_exit.argtypes = [c_void_p]
pthread_exit.__doc__ = \
"""void pthread_exit(void * p1)
/usr/include/pthread.h:305"""
# /usr/include/pthread.h 306
pthread_getconcurrency = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_getconcurrency
pthread_getconcurrency.restype = c_int
# pthread_getconcurrency()
pthread_getconcurrency.argtypes = []
pthread_getconcurrency.__doc__ = \
"""int pthread_getconcurrency()
/usr/include/pthread.h:306"""
# /usr/include/pthread.h 307
pthread_getschedparam = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_getschedparam
pthread_getschedparam.restype = c_int
# pthread_getschedparam(p1, p2, p3)
pthread_getschedparam.argtypes = [pthread_t, POINTER(c_int), POINTER(sched_param)]
pthread_getschedparam.__doc__ = \
"""int pthread_getschedparam(pthread_t p1, int * p2, sched_param * p3)
/usr/include/pthread.h:307"""
# /usr/include/pthread.h 308
pthread_getspecific = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_getspecific
pthread_getspecific.restype = c_void_p
# pthread_getspecific(p1)
pthread_getspecific.argtypes = [pthread_key_t]
pthread_getspecific.__doc__ = \
"""void * pthread_getspecific(pthread_key_t p1)
/usr/include/pthread.h:308"""
# /usr/include/pthread.h 309
pthread_join = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_join
pthread_join.restype = c_int
# pthread_join(p1, p2)
pthread_join.argtypes = [pthread_t, POINTER(c_void_p)]
pthread_join.__doc__ = \
"""int pthread_join(pthread_t p1, void * * p2)
/usr/include/pthread.h:309"""
# /usr/include/pthread.h 310
pthread_key_create = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_key_create
pthread_key_create.restype = c_int
# pthread_key_create(p1, p2)
pthread_key_create.argtypes = [POINTER(pthread_key_t), CFUNCTYPE(None, c_void_p)]
pthread_key_create.__doc__ = \
"""int pthread_key_create(pthread_key_t * p1, unknown * p2)
/usr/include/pthread.h:310"""
# /usr/include/pthread.h 311
pthread_key_delete = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_key_delete
pthread_key_delete.restype = c_int
# pthread_key_delete(p1)
pthread_key_delete.argtypes = [pthread_key_t]
pthread_key_delete.__doc__ = \
"""int pthread_key_delete(pthread_key_t p1)
/usr/include/pthread.h:311"""
# /usr/include/pthread.h 312
pthread_mutex_destroy = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutex_destroy
pthread_mutex_destroy.restype = c_int
# pthread_mutex_destroy(p1)
pthread_mutex_destroy.argtypes = [POINTER(pthread_mutex_t)]
pthread_mutex_destroy.__doc__ = \
"""int pthread_mutex_destroy(pthread_mutex_t * p1)
/usr/include/pthread.h:312"""
# /usr/include/pthread.h 313
pthread_mutex_getprioceiling = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutex_getprioceiling
pthread_mutex_getprioceiling.restype = c_int
# pthread_mutex_getprioceiling(p1, p2)
pthread_mutex_getprioceiling.argtypes = [POINTER(pthread_mutex_t), POINTER(c_int)]
pthread_mutex_getprioceiling.__doc__ = \
"""int pthread_mutex_getprioceiling(unknown * p1, int * p2)
/usr/include/pthread.h:313"""
# /usr/include/pthread.h 314
pthread_mutex_init = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutex_init
pthread_mutex_init.restype = c_int
# pthread_mutex_init(p1, p2)
pthread_mutex_init.argtypes = [POINTER(pthread_mutex_t), POINTER(pthread_mutexattr_t)]
pthread_mutex_init.__doc__ = \
"""int pthread_mutex_init(pthread_mutex_t * p1, unknown * p2)
/usr/include/pthread.h:314"""
# /usr/include/pthread.h 315
pthread_mutex_lock = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutex_lock
pthread_mutex_lock.restype = c_int
# pthread_mutex_lock(p1)
pthread_mutex_lock.argtypes = [POINTER(pthread_mutex_t)]
pthread_mutex_lock.__doc__ = \
"""int pthread_mutex_lock(pthread_mutex_t * p1)
/usr/include/pthread.h:315"""
# /usr/include/pthread.h 316
pthread_mutex_setprioceiling = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutex_setprioceiling
pthread_mutex_setprioceiling.restype = c_int
# pthread_mutex_setprioceiling(p1, p2, p3)
pthread_mutex_setprioceiling.argtypes = [POINTER(pthread_mutex_t), c_int, POINTER(c_int)]
pthread_mutex_setprioceiling.__doc__ = \
"""int pthread_mutex_setprioceiling(pthread_mutex_t * p1, int p2, int * p3)
/usr/include/pthread.h:316"""
# /usr/include/pthread.h 317
pthread_mutex_trylock = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutex_trylock
pthread_mutex_trylock.restype = c_int
# pthread_mutex_trylock(p1)
pthread_mutex_trylock.argtypes = [POINTER(pthread_mutex_t)]
pthread_mutex_trylock.__doc__ = \
"""int pthread_mutex_trylock(pthread_mutex_t * p1)
/usr/include/pthread.h:317"""
# /usr/include/pthread.h 318
pthread_mutex_unlock = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutex_unlock
pthread_mutex_unlock.restype = c_int
# pthread_mutex_unlock(p1)
pthread_mutex_unlock.argtypes = [POINTER(pthread_mutex_t)]
pthread_mutex_unlock.__doc__ = \
"""int pthread_mutex_unlock(pthread_mutex_t * p1)
/usr/include/pthread.h:318"""
# /usr/include/pthread.h 319
pthread_mutexattr_destroy = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutexattr_destroy
pthread_mutexattr_destroy.restype = c_int
# pthread_mutexattr_destroy(p1)
pthread_mutexattr_destroy.argtypes = [POINTER(pthread_mutexattr_t)]
pthread_mutexattr_destroy.__doc__ = \
"""int pthread_mutexattr_destroy(pthread_mutexattr_t * p1)
/usr/include/pthread.h:319"""
# /usr/include/pthread.h 320
pthread_mutexattr_getprioceiling = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutexattr_getprioceiling
pthread_mutexattr_getprioceiling.restype = c_int
# pthread_mutexattr_getprioceiling(p1, p2)
pthread_mutexattr_getprioceiling.argtypes = [POINTER(pthread_mutexattr_t), POINTER(c_int)]
pthread_mutexattr_getprioceiling.__doc__ = \
"""int pthread_mutexattr_getprioceiling(unknown * p1, int * p2)
/usr/include/pthread.h:320"""
# /usr/include/pthread.h 321
pthread_mutexattr_getprotocol = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutexattr_getprotocol
pthread_mutexattr_getprotocol.restype = c_int
# pthread_mutexattr_getprotocol(p1, p2)
pthread_mutexattr_getprotocol.argtypes = [POINTER(pthread_mutexattr_t), POINTER(c_int)]
pthread_mutexattr_getprotocol.__doc__ = \
"""int pthread_mutexattr_getprotocol(unknown * p1, int * p2)
/usr/include/pthread.h:321"""
# /usr/include/pthread.h 322
pthread_mutexattr_getpshared = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutexattr_getpshared
pthread_mutexattr_getpshared.restype = c_int
# pthread_mutexattr_getpshared(p1, p2)
pthread_mutexattr_getpshared.argtypes = [POINTER(pthread_mutexattr_t), POINTER(c_int)]
pthread_mutexattr_getpshared.__doc__ = \
"""int pthread_mutexattr_getpshared(unknown * p1, int * p2)
/usr/include/pthread.h:322"""
# /usr/include/pthread.h 323
pthread_mutexattr_gettype = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutexattr_gettype
pthread_mutexattr_gettype.restype = c_int
# pthread_mutexattr_gettype(p1, p2)
pthread_mutexattr_gettype.argtypes = [POINTER(pthread_mutexattr_t), POINTER(c_int)]
pthread_mutexattr_gettype.__doc__ = \
"""int pthread_mutexattr_gettype(unknown * p1, int * p2)
/usr/include/pthread.h:323"""
# /usr/include/pthread.h 324
pthread_mutexattr_init = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutexattr_init
pthread_mutexattr_init.restype = c_int
# pthread_mutexattr_init(p1)
pthread_mutexattr_init.argtypes = [POINTER(pthread_mutexattr_t)]
pthread_mutexattr_init.__doc__ = \
"""int pthread_mutexattr_init(pthread_mutexattr_t * p1)
/usr/include/pthread.h:324"""
# /usr/include/pthread.h 325
pthread_mutexattr_setprioceiling = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutexattr_setprioceiling
pthread_mutexattr_setprioceiling.restype = c_int
# pthread_mutexattr_setprioceiling(p1, p2)
pthread_mutexattr_setprioceiling.argtypes = [POINTER(pthread_mutexattr_t), c_int]
pthread_mutexattr_setprioceiling.__doc__ = \
"""int pthread_mutexattr_setprioceiling(pthread_mutexattr_t * p1, int p2)
/usr/include/pthread.h:325"""
# /usr/include/pthread.h 326
pthread_mutexattr_setprotocol = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutexattr_setprotocol
pthread_mutexattr_setprotocol.restype = c_int
# pthread_mutexattr_setprotocol(p1, p2)
pthread_mutexattr_setprotocol.argtypes = [POINTER(pthread_mutexattr_t), c_int]
pthread_mutexattr_setprotocol.__doc__ = \
"""int pthread_mutexattr_setprotocol(pthread_mutexattr_t * p1, int p2)
/usr/include/pthread.h:326"""
# /usr/include/pthread.h 327
pthread_mutexattr_setpshared = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutexattr_setpshared
pthread_mutexattr_setpshared.restype = c_int
# pthread_mutexattr_setpshared(p1, p2)
pthread_mutexattr_setpshared.argtypes = [POINTER(pthread_mutexattr_t), c_int]
pthread_mutexattr_setpshared.__doc__ = \
"""int pthread_mutexattr_setpshared(pthread_mutexattr_t * p1, int p2)
/usr/include/pthread.h:327"""
# /usr/include/pthread.h 328
pthread_mutexattr_settype = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mutexattr_settype
pthread_mutexattr_settype.restype = c_int
# pthread_mutexattr_settype(p1, p2)
pthread_mutexattr_settype.argtypes = [POINTER(pthread_mutexattr_t), c_int]
pthread_mutexattr_settype.__doc__ = \
"""int pthread_mutexattr_settype(pthread_mutexattr_t * p1, int p2)
/usr/include/pthread.h:328"""
# /usr/include/pthread.h 329
pthread_once = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_once
pthread_once.restype = c_int
# pthread_once(p1, p2)
pthread_once.argtypes = [POINTER(pthread_once_t), CFUNCTYPE(None)]
pthread_once.__doc__ = \
"""int pthread_once(pthread_once_t * p1, unknown * p2)
/usr/include/pthread.h:329"""
# /usr/include/pthread.h 330
pthread_rwlock_destroy = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlock_destroy
pthread_rwlock_destroy.restype = c_int
# pthread_rwlock_destroy(p1)
pthread_rwlock_destroy.argtypes = [POINTER(pthread_rwlock_t)]
pthread_rwlock_destroy.__doc__ = \
"""int pthread_rwlock_destroy(pthread_rwlock_t * p1)
/usr/include/pthread.h:330"""
# /usr/include/pthread.h 331
pthread_rwlock_init = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlock_init
pthread_rwlock_init.restype = c_int
# pthread_rwlock_init(p1, p2)
pthread_rwlock_init.argtypes = [POINTER(pthread_rwlock_t), POINTER(pthread_rwlockattr_t)]
pthread_rwlock_init.__doc__ = \
"""int pthread_rwlock_init(pthread_rwlock_t * p1, unknown * p2)
/usr/include/pthread.h:331"""
# /usr/include/pthread.h 332
pthread_rwlock_rdlock = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlock_rdlock
pthread_rwlock_rdlock.restype = c_int
# pthread_rwlock_rdlock(p1)
pthread_rwlock_rdlock.argtypes = [POINTER(pthread_rwlock_t)]
pthread_rwlock_rdlock.__doc__ = \
"""int pthread_rwlock_rdlock(pthread_rwlock_t * p1)
/usr/include/pthread.h:332"""
# /usr/include/pthread.h 333
pthread_rwlock_tryrdlock = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlock_tryrdlock
pthread_rwlock_tryrdlock.restype = c_int
# pthread_rwlock_tryrdlock(p1)
pthread_rwlock_tryrdlock.argtypes = [POINTER(pthread_rwlock_t)]
pthread_rwlock_tryrdlock.__doc__ = \
"""int pthread_rwlock_tryrdlock(pthread_rwlock_t * p1)
/usr/include/pthread.h:333"""
# /usr/include/pthread.h 334
pthread_rwlock_trywrlock = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlock_trywrlock
pthread_rwlock_trywrlock.restype = c_int
# pthread_rwlock_trywrlock(p1)
pthread_rwlock_trywrlock.argtypes = [POINTER(pthread_rwlock_t)]
pthread_rwlock_trywrlock.__doc__ = \
"""int pthread_rwlock_trywrlock(pthread_rwlock_t * p1)
/usr/include/pthread.h:334"""
# /usr/include/pthread.h 335
pthread_rwlock_wrlock = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlock_wrlock
pthread_rwlock_wrlock.restype = c_int
# pthread_rwlock_wrlock(p1)
pthread_rwlock_wrlock.argtypes = [POINTER(pthread_rwlock_t)]
pthread_rwlock_wrlock.__doc__ = \
"""int pthread_rwlock_wrlock(pthread_rwlock_t * p1)
/usr/include/pthread.h:335"""
# /usr/include/pthread.h 336
pthread_rwlock_unlock = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlock_unlock
pthread_rwlock_unlock.restype = c_int
# pthread_rwlock_unlock(p1)
pthread_rwlock_unlock.argtypes = [POINTER(pthread_rwlock_t)]
pthread_rwlock_unlock.__doc__ = \
"""int pthread_rwlock_unlock(pthread_rwlock_t * p1)
/usr/include/pthread.h:336"""
# /usr/include/pthread.h 337
pthread_rwlockattr_destroy = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlockattr_destroy
pthread_rwlockattr_destroy.restype = c_int
# pthread_rwlockattr_destroy(p1)
pthread_rwlockattr_destroy.argtypes = [POINTER(pthread_rwlockattr_t)]
pthread_rwlockattr_destroy.__doc__ = \
"""int pthread_rwlockattr_destroy(pthread_rwlockattr_t * p1)
/usr/include/pthread.h:337"""
# /usr/include/pthread.h 339
pthread_rwlockattr_getpshared = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlockattr_getpshared
pthread_rwlockattr_getpshared.restype = c_int
# pthread_rwlockattr_getpshared(p1, p2)
pthread_rwlockattr_getpshared.argtypes = [POINTER(pthread_rwlockattr_t), POINTER(c_int)]
pthread_rwlockattr_getpshared.__doc__ = \
"""int pthread_rwlockattr_getpshared(unknown * p1, int * p2)
/usr/include/pthread.h:339"""
# /usr/include/pthread.h 340
pthread_rwlockattr_init = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlockattr_init
pthread_rwlockattr_init.restype = c_int
# pthread_rwlockattr_init(p1)
pthread_rwlockattr_init.argtypes = [POINTER(pthread_rwlockattr_t)]
pthread_rwlockattr_init.__doc__ = \
"""int pthread_rwlockattr_init(pthread_rwlockattr_t * p1)
/usr/include/pthread.h:340"""
# /usr/include/pthread.h 342
pthread_rwlockattr_setpshared = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_rwlockattr_setpshared
pthread_rwlockattr_setpshared.restype = c_int
# pthread_rwlockattr_setpshared(p1, p2)
pthread_rwlockattr_setpshared.argtypes = [POINTER(pthread_rwlockattr_t), c_int]
pthread_rwlockattr_setpshared.__doc__ = \
"""int pthread_rwlockattr_setpshared(pthread_rwlockattr_t * p1, int p2)
/usr/include/pthread.h:342"""
# /usr/include/pthread.h 343
pthread_self = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_self
pthread_self.restype = pthread_t
# pthread_self()
pthread_self.argtypes = []
pthread_self.__doc__ = \
"""pthread_t pthread_self()
/usr/include/pthread.h:343"""
# /usr/include/pthread.h 345
pthread_setcancelstate = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_setcancelstate
pthread_setcancelstate.restype = c_int
# pthread_setcancelstate(p1, p2)
pthread_setcancelstate.argtypes = [c_int, POINTER(c_int)]
pthread_setcancelstate.__doc__ = \
"""int pthread_setcancelstate(int p1, int * p2)
/usr/include/pthread.h:345"""
# /usr/include/pthread.h 346
pthread_setcanceltype = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_setcanceltype
pthread_setcanceltype.restype = c_int
# pthread_setcanceltype(p1, p2)
pthread_setcanceltype.argtypes = [c_int, POINTER(c_int)]
pthread_setcanceltype.__doc__ = \
"""int pthread_setcanceltype(int p1, int * p2)
/usr/include/pthread.h:346"""
# /usr/include/pthread.h 347
pthread_setconcurrency = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_setconcurrency
pthread_setconcurrency.restype = c_int
# pthread_setconcurrency(p1)
pthread_setconcurrency.argtypes = [c_int]
pthread_setconcurrency.__doc__ = \
"""int pthread_setconcurrency(int p1)
/usr/include/pthread.h:347"""
# /usr/include/pthread.h 350
pthread_setschedparam = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_setschedparam
pthread_setschedparam.restype = c_int
# pthread_setschedparam(p1, p2, p3)
pthread_setschedparam.argtypes = [pthread_t, c_int, POINTER(sched_param)]
pthread_setschedparam.__doc__ = \
"""int pthread_setschedparam(pthread_t p1, int p2, unknown * p3)
/usr/include/pthread.h:350"""
# /usr/include/pthread.h 352
pthread_setspecific = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_setspecific
pthread_setspecific.restype = c_int
# pthread_setspecific(p1, p2)
pthread_setspecific.argtypes = [pthread_key_t, c_void_p]
pthread_setspecific.__doc__ = \
"""int pthread_setspecific(pthread_key_t p1, unknown * p2)
/usr/include/pthread.h:352"""
# /usr/include/pthread.h 353
pthread_testcancel = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_testcancel
pthread_testcancel.restype = None
# pthread_testcancel()
pthread_testcancel.argtypes = []
pthread_testcancel.__doc__ = \
"""void pthread_testcancel()
/usr/include/pthread.h:353"""
# /usr/include/pthread.h 357
pthread_is_threaded_np = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_is_threaded_np
pthread_is_threaded_np.restype = c_int
# pthread_is_threaded_np()
pthread_is_threaded_np.argtypes = []
pthread_is_threaded_np.__doc__ = \
"""int pthread_is_threaded_np()
/usr/include/pthread.h:357"""
# /usr/include/pthread.h 360
pthread_main_np = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_main_np
pthread_main_np.restype = c_int
# pthread_main_np()
pthread_main_np.argtypes = []
pthread_main_np.__doc__ = \
"""int pthread_main_np()
/usr/include/pthread.h:360"""
# /usr/include/pthread.h 363
pthread_mach_thread_np = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_mach_thread_np
pthread_mach_thread_np.restype = mach_port_t
# pthread_mach_thread_np(p1)
pthread_mach_thread_np.argtypes = [pthread_t]
pthread_mach_thread_np.__doc__ = \
"""mach_port_t pthread_mach_thread_np(pthread_t p1)
/usr/include/pthread.h:363"""
# /usr/include/pthread.h 364
pthread_get_stacksize_np = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_get_stacksize_np
pthread_get_stacksize_np.restype = size_t
# pthread_get_stacksize_np(p1)
pthread_get_stacksize_np.argtypes = [pthread_t]
pthread_get_stacksize_np.__doc__ = \
"""size_t pthread_get_stacksize_np(pthread_t p1)
/usr/include/pthread.h:364"""
# /usr/include/pthread.h 365
pthread_get_stackaddr_np = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_get_stackaddr_np
pthread_get_stackaddr_np.restype = c_void_p
# pthread_get_stackaddr_np(p1)
pthread_get_stackaddr_np.argtypes = [pthread_t]
pthread_get_stackaddr_np.__doc__ = \
"""void * pthread_get_stackaddr_np(pthread_t p1)
/usr/include/pthread.h:365"""
# /usr/include/pthread.h 368
pthread_cond_signal_thread_np = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_cond_signal_thread_np
pthread_cond_signal_thread_np.restype = c_int
# pthread_cond_signal_thread_np(p1, p2)
pthread_cond_signal_thread_np.argtypes = [POINTER(pthread_cond_t), pthread_t]
pthread_cond_signal_thread_np.__doc__ = \
"""int pthread_cond_signal_thread_np(pthread_cond_t * p1, pthread_t p2)
/usr/include/pthread.h:368"""
# /usr/include/pthread.h 373
pthread_cond_timedwait_relative_np = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_cond_timedwait_relative_np
pthread_cond_timedwait_relative_np.restype = c_int
# pthread_cond_timedwait_relative_np(p1, p2, p3)
pthread_cond_timedwait_relative_np.argtypes = [POINTER(pthread_cond_t), POINTER(pthread_mutex_t), POINTER(timespec)]
pthread_cond_timedwait_relative_np.__doc__ = \
"""int pthread_cond_timedwait_relative_np(pthread_cond_t * p1, pthread_mutex_t * p2, unknown * p3)
/usr/include/pthread.h:373"""
# /usr/include/pthread.h 379
pthread_create_suspended_np = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_create_suspended_np
pthread_create_suspended_np.restype = c_int
# pthread_create_suspended_np(p1, p2, p3, p4)
pthread_create_suspended_np.argtypes = [POINTER(pthread_t), POINTER(pthread_attr_t), CFUNCTYPE(c_void_p, c_void_p), c_void_p]
pthread_create_suspended_np.__doc__ = \
"""int pthread_create_suspended_np(pthread_t * p1, unknown * p2, unknown * p3, void * p4)
/usr/include/pthread.h:379"""
# /usr/include/pthread.h 380
pthread_kill = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_kill
pthread_kill.restype = c_int
# pthread_kill(p1, p2)
pthread_kill.argtypes = [pthread_t, c_int]
pthread_kill.__doc__ = \
"""int pthread_kill(pthread_t p1, int p2)
/usr/include/pthread.h:380"""
# /usr/include/pthread.h 382
pthread_from_mach_thread_np = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_from_mach_thread_np
pthread_from_mach_thread_np.restype = pthread_t
# pthread_from_mach_thread_np(p1)
pthread_from_mach_thread_np.argtypes = [mach_port_t]
pthread_from_mach_thread_np.__doc__ = \
"""pthread_t pthread_from_mach_thread_np(mach_port_t p1)
/usr/include/pthread.h:382"""
# /usr/include/pthread.h 384
pthread_sigmask = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_sigmask
pthread_sigmask.restype = c_int
# pthread_sigmask(p1, p2, p3)
pthread_sigmask.argtypes = [c_int, POINTER(sigset_t), POINTER(sigset_t)]
pthread_sigmask.__doc__ = \
"""int pthread_sigmask(int p1, unknown * p2, sigset_t * p3)
/usr/include/pthread.h:384"""
# /usr/include/pthread.h 385
pthread_yield_np = _libraries['/usr/local/lib/libftd2xx.dylib'].pthread_yield_np
pthread_yield_np.restype = None
# pthread_yield_np()
pthread_yield_np.argtypes = []
pthread_yield_np.__doc__ = \
"""void pthread_yield_np()
/usr/include/pthread.h:385"""
# /usr/include/sched.h 38
sched_yield = _libraries['/usr/local/lib/libftd2xx.dylib'].sched_yield
sched_yield.restype = c_int
# sched_yield()
sched_yield.argtypes = []
sched_yield.__doc__ = \
"""int sched_yield()
/usr/include/sched.h:38"""
# /usr/include/sched.h 39
sched_get_priority_min = _libraries['/usr/local/lib/libftd2xx.dylib'].sched_get_priority_min
sched_get_priority_min.restype = c_int
# sched_get_priority_min(p1)
sched_get_priority_min.argtypes = [c_int]
sched_get_priority_min.__doc__ = \
"""int sched_get_priority_min(int p1)
/usr/include/sched.h:39"""
# /usr/include/sched.h 40
sched_get_priority_max = _libraries['/usr/local/lib/libftd2xx.dylib'].sched_get_priority_max
sched_get_priority_max.restype = c_int
# sched_get_priority_max(p1)
sched_get_priority_max.argtypes = [c_int]
sched_get_priority_max.__doc__ = \
"""int sched_get_priority_max(int p1)
/usr/include/sched.h:40"""
# /usr/include/sys/_structs.h 184
class fd_set(Structure):
    pass
# /usr/include/sys/_structs.h 101
class timeval(Structure):
    pass
# /usr/include/sys/_select.h 47
select = _libraries['/usr/local/lib/libftd2xx.dylib'].select
select.restype = c_int
# select(p1, p2, p3, p4, p5)
select.argtypes = [c_int, POINTER(fd_set), POINTER(fd_set), POINTER(fd_set), POINTER(timeval)]
select.__doc__ = \
"""int select(int p1, fd_set * p2, fd_set * p3, fd_set * p4, timeval * p5)
/usr/include/sys/_select.h:47"""
__darwin_suseconds_t = __int32_t
timeval._fields_ = [
    # /usr/include/sys/_structs.h 101
    ('tv_sec', __darwin_time_t),
    ('tv_usec', __darwin_suseconds_t),
]
fd_set._fields_ = [
    # /usr/include/sys/_structs.h 184
    ('fds_bits', __int32_t * 32),
]
# /usr/include/sys/_types.h 59
class __darwin_pthread_handler_rec(Structure):
    pass
__darwin_pthread_handler_rec._fields_ = [
    # /usr/include/sys/_types.h 59
    ('__routine', CFUNCTYPE(None, c_void_p)),
    ('__arg', c_void_p),
    ('__next', POINTER(__darwin_pthread_handler_rec)),
]
_opaque_pthread_attr_t._fields_ = [
    # /usr/include/sys/_types.h 64
    ('__sig', c_long),
    ('__opaque', c_char * 36),
]
_opaque_pthread_cond_t._fields_ = [
    # /usr/include/sys/_types.h 65
    ('__sig', c_long),
    ('__opaque', c_char * 24),
]
_opaque_pthread_condattr_t._fields_ = [
    # /usr/include/sys/_types.h 66
    ('__sig', c_long),
    ('__opaque', c_char * 4),
]
_opaque_pthread_mutex_t._fields_ = [
    # /usr/include/sys/_types.h 67
    ('__sig', c_long),
    ('__opaque', c_char * 40),
]
_opaque_pthread_mutexattr_t._fields_ = [
    # /usr/include/sys/_types.h 68
    ('__sig', c_long),
    ('__opaque', c_char * 8),
]
_opaque_pthread_once_t._fields_ = [
    # /usr/include/sys/_types.h 69
    ('__sig', c_long),
    ('__opaque', c_char * 4),
]
_opaque_pthread_rwlock_t._fields_ = [
    # /usr/include/sys/_types.h 70
    ('__sig', c_long),
    ('__opaque', c_char * 124),
]
_opaque_pthread_rwlockattr_t._fields_ = [
    # /usr/include/sys/_types.h 71
    ('__sig', c_long),
    ('__opaque', c_char * 12),
]
_opaque_pthread_t._fields_ = [
    # /usr/include/sys/_types.h 72
    ('__sig', c_long),
    ('__cleanup_stack', POINTER(__darwin_pthread_handler_rec)),
    ('__opaque', c_char * 596),
]
__darwin_blkcnt_t = __int64_t
__darwin_blksize_t = __int32_t
__darwin_dev_t = __int32_t
__darwin_fsblkcnt_t = c_uint
__darwin_fsfilcnt_t = c_uint
__darwin_gid_t = __uint32_t
__darwin_id_t = __uint32_t
__darwin_ino64_t = __uint64_t
__darwin_ino_t = __uint32_t
__darwin_mode_t = __uint16_t
__darwin_off_t = __int64_t
__darwin_pid_t = __int32_t
__darwin_uid_t = __uint32_t
__darwin_useconds_t = __uint32_t
__darwin_uuid_t = c_ubyte * 16
suseconds_t = __darwin_suseconds_t
# /usr/include/sys/time.h 93
class itimerval(Structure):
    pass
itimerval._fields_ = [
    # /usr/include/sys/time.h 93
    ('it_interval', timeval),
    ('it_value', timeval),
]
# /usr/include/sys/time.h 144
class timezone(Structure):
    pass
timezone._fields_ = [
    # /usr/include/sys/time.h 144
    ('tz_minuteswest', c_int),
    ('tz_dsttime', c_int),
]
# /usr/include/sys/time.h 187
class clockinfo(Structure):
    pass
clockinfo._fields_ = [
    # /usr/include/sys/time.h 187
    ('hz', c_int),
    ('tick', c_int),
    ('tickadj', c_int),
    ('stathz', c_int),
    ('profhz', c_int),
]
# /usr/include/sys/time.h 204
adjtime = _libraries['/usr/local/lib/libftd2xx.dylib'].adjtime
adjtime.restype = c_int
# adjtime(p1, p2)
adjtime.argtypes = [POINTER(timeval), POINTER(timeval)]
adjtime.__doc__ = \
"""int adjtime(unknown * p1, timeval * p2)
/usr/include/sys/time.h:204"""
# /usr/include/sys/time.h 205
futimes = _libraries['/usr/local/lib/libftd2xx.dylib'].futimes
futimes.restype = c_int
# futimes(p1, p2)
futimes.argtypes = [c_int, POINTER(timeval)]
futimes.__doc__ = \
"""int futimes(int p1, unknown * p2)
/usr/include/sys/time.h:205"""
# /usr/include/sys/time.h 206
lutimes = _libraries['/usr/local/lib/libftd2xx.dylib'].lutimes
lutimes.restype = c_int
# lutimes(p1, p2)
lutimes.argtypes = [STRING, POINTER(timeval)]
lutimes.__doc__ = \
"""int lutimes(unknown * p1, unknown * p2)
/usr/include/sys/time.h:206"""
# /usr/include/sys/time.h 207
settimeofday = _libraries['/usr/local/lib/libftd2xx.dylib'].settimeofday
settimeofday.restype = c_int
# settimeofday(p1, p2)
settimeofday.argtypes = [POINTER(timeval), POINTER(timezone)]
settimeofday.__doc__ = \
"""int settimeofday(unknown * p1, unknown * p2)
/usr/include/sys/time.h:207"""
# /usr/include/sys/time.h 210
getitimer = _libraries['/usr/local/lib/libftd2xx.dylib'].getitimer
getitimer.restype = c_int
# getitimer(p1, p2)
getitimer.argtypes = [c_int, POINTER(itimerval)]
getitimer.__doc__ = \
"""int getitimer(int p1, itimerval * p2)
/usr/include/sys/time.h:210"""
# /usr/include/sys/time.h 211
gettimeofday = _libraries['/usr/local/lib/libftd2xx.dylib'].gettimeofday
gettimeofday.restype = c_int
# gettimeofday(p1, p2)
gettimeofday.argtypes = [POINTER(timeval), c_void_p]
gettimeofday.__doc__ = \
"""int gettimeofday(timeval * p1, void * p2)
/usr/include/sys/time.h:211"""
# /usr/include/sys/time.h 216
setitimer = _libraries['/usr/local/lib/libftd2xx.dylib'].setitimer
setitimer.restype = c_int
# setitimer(p1, p2, p3)
setitimer.argtypes = [c_int, POINTER(itimerval), POINTER(itimerval)]
setitimer.__doc__ = \
"""int setitimer(int p1, unknown * p2, itimerval * p3)
/usr/include/sys/time.h:216"""
# /usr/include/sys/time.h 217
utimes = _libraries['/usr/local/lib/libftd2xx.dylib'].utimes
utimes.restype = c_int
# utimes(p1, p2)
utimes.argtypes = [STRING, POINTER(timeval)]
utimes.__doc__ = \
"""int utimes(unknown * p1, unknown * p2)
/usr/include/sys/time.h:217"""
clock_t = __darwin_clock_t
time_t = __darwin_time_t
# /usr/include/time.h 90
class tm(Structure):
    pass
tm._fields_ = [
    # /usr/include/time.h 90
    ('tm_sec', c_int),
    ('tm_min', c_int),
    ('tm_hour', c_int),
    ('tm_mday', c_int),
    ('tm_mon', c_int),
    ('tm_year', c_int),
    ('tm_wday', c_int),
    ('tm_yday', c_int),
    ('tm_isdst', c_int),
    ('tm_gmtoff', c_long),
    ('tm_zone', STRING),
]
# /usr/include/time.h 123
asctime = _libraries['/usr/local/lib/libftd2xx.dylib'].asctime
asctime.restype = STRING
# asctime(p1)
asctime.argtypes = [POINTER(tm)]
asctime.__doc__ = \
"""char * asctime(unknown * p1)
/usr/include/time.h:123"""
# /usr/include/time.h 124
clock = _libraries['/usr/local/lib/libftd2xx.dylib'].clock
clock.restype = clock_t
# clock()
clock.argtypes = []
clock.__doc__ = \
"""clock_t clock()
/usr/include/time.h:124"""
# /usr/include/time.h 125
ctime = _libraries['/usr/local/lib/libftd2xx.dylib'].ctime
ctime.restype = STRING
# ctime(p1)
ctime.argtypes = [POINTER(time_t)]
ctime.__doc__ = \
"""char * ctime(unknown * p1)
/usr/include/time.h:125"""
# /usr/include/time.h 126
difftime = _libraries['/usr/local/lib/libftd2xx.dylib'].difftime
difftime.restype = c_double
# difftime(p1, p2)
difftime.argtypes = [time_t, time_t]
difftime.__doc__ = \
"""double difftime(time_t p1, time_t p2)
/usr/include/time.h:126"""
# /usr/include/time.h 127
getdate = _libraries['/usr/local/lib/libftd2xx.dylib'].getdate
getdate.restype = POINTER(tm)
# getdate(p1)
getdate.argtypes = [STRING]
getdate.__doc__ = \
"""tm * getdate(unknown * p1)
/usr/include/time.h:127"""
# /usr/include/time.h 128
gmtime = _libraries['/usr/local/lib/libftd2xx.dylib'].gmtime
gmtime.restype = POINTER(tm)
# gmtime(p1)
gmtime.argtypes = [POINTER(time_t)]
gmtime.__doc__ = \
"""tm * gmtime(unknown * p1)
/usr/include/time.h:128"""
# /usr/include/time.h 129
localtime = _libraries['/usr/local/lib/libftd2xx.dylib'].localtime
localtime.restype = POINTER(tm)
# localtime(p1)
localtime.argtypes = [POINTER(time_t)]
localtime.__doc__ = \
"""tm * localtime(unknown * p1)
/usr/include/time.h:129"""
# /usr/include/time.h 130
mktime = _libraries['/usr/local/lib/libftd2xx.dylib'].mktime
mktime.restype = time_t
# mktime(p1)
mktime.argtypes = [POINTER(tm)]
mktime.__doc__ = \
"""time_t mktime(tm * p1)
/usr/include/time.h:130"""
# /usr/include/time.h 131
strftime = _libraries['/usr/local/lib/libftd2xx.dylib'].strftime
strftime.restype = size_t
# strftime(p1, p2, p3, p4)
strftime.argtypes = [STRING, size_t, STRING, POINTER(tm)]
strftime.__doc__ = \
"""size_t strftime(char * p1, size_t p2, unknown * p3, unknown * p4)
/usr/include/time.h:131"""
# /usr/include/time.h 132
strptime = _libraries['/usr/local/lib/libftd2xx.dylib'].strptime
strptime.restype = STRING
# strptime(p1, p2, p3)
strptime.argtypes = [STRING, STRING, POINTER(tm)]
strptime.__doc__ = \
"""char * strptime(unknown * p1, unknown * p2, tm * p3)
/usr/include/time.h:132"""
# /usr/include/time.h 133
time = _libraries['/usr/local/lib/libftd2xx.dylib'].time
time.restype = time_t
# time(p1)
time.argtypes = [POINTER(time_t)]
time.__doc__ = \
"""time_t time(time_t * p1)
/usr/include/time.h:133"""
# /usr/include/time.h 136
tzset = _libraries['/usr/local/lib/libftd2xx.dylib'].tzset
tzset.restype = None
# tzset()
tzset.argtypes = []
tzset.__doc__ = \
"""void tzset()
/usr/include/time.h:136"""
# /usr/include/time.h 140
asctime_r = _libraries['/usr/local/lib/libftd2xx.dylib'].asctime_r
asctime_r.restype = STRING
# asctime_r(p1, p2)
asctime_r.argtypes = [POINTER(tm), STRING]
asctime_r.__doc__ = \
"""char * asctime_r(unknown * p1, char * p2)
/usr/include/time.h:140"""
# /usr/include/time.h 141
ctime_r = _libraries['/usr/local/lib/libftd2xx.dylib'].ctime_r
ctime_r.restype = STRING
# ctime_r(p1, p2)
ctime_r.argtypes = [POINTER(time_t), STRING]
ctime_r.__doc__ = \
"""char * ctime_r(unknown * p1, char * p2)
/usr/include/time.h:141"""
# /usr/include/time.h 142
gmtime_r = _libraries['/usr/local/lib/libftd2xx.dylib'].gmtime_r
gmtime_r.restype = POINTER(tm)
# gmtime_r(p1, p2)
gmtime_r.argtypes = [POINTER(time_t), POINTER(tm)]
gmtime_r.__doc__ = \
"""tm * gmtime_r(unknown * p1, tm * p2)
/usr/include/time.h:142"""
# /usr/include/time.h 143
localtime_r = _libraries['/usr/local/lib/libftd2xx.dylib'].localtime_r
localtime_r.restype = POINTER(tm)
# localtime_r(p1, p2)
localtime_r.argtypes = [POINTER(time_t), POINTER(tm)]
localtime_r.__doc__ = \
"""tm * localtime_r(unknown * p1, tm * p2)
/usr/include/time.h:143"""
# /usr/include/time.h 146
posix2time = _libraries['/usr/local/lib/libftd2xx.dylib'].posix2time
posix2time.restype = time_t
# posix2time(p1)
posix2time.argtypes = [time_t]
posix2time.__doc__ = \
"""time_t posix2time(time_t p1)
/usr/include/time.h:146"""
# /usr/include/time.h 150
tzsetwall = _libraries['/usr/local/lib/libftd2xx.dylib'].tzsetwall
tzsetwall.restype = None
# tzsetwall()
tzsetwall.argtypes = []
tzsetwall.__doc__ = \
"""void tzsetwall()
/usr/include/time.h:150"""
# /usr/include/time.h 151
time2posix = _libraries['/usr/local/lib/libftd2xx.dylib'].time2posix
time2posix.restype = time_t
# time2posix(p1)
time2posix.argtypes = [time_t]
time2posix.__doc__ = \
"""time_t time2posix(time_t p1)
/usr/include/time.h:151"""
# /usr/include/time.h 152
timelocal = _libraries['/usr/local/lib/libftd2xx.dylib'].timelocal
timelocal.restype = time_t
# timelocal(p1)
timelocal.argtypes = [POINTER(tm)]
timelocal.__doc__ = \
"""time_t timelocal(unknown p1)
/usr/include/time.h:152"""
# /usr/include/time.h 153
timegm = _libraries['/usr/local/lib/libftd2xx.dylib'].timegm
timegm.restype = time_t
# timegm(p1)
timegm.argtypes = [POINTER(tm)]
timegm.__doc__ = \
"""time_t timegm(unknown p1)
/usr/include/time.h:153"""
# /usr/include/time.h 157
nanosleep = _libraries['/usr/local/lib/libftd2xx.dylib'].nanosleep
nanosleep.restype = c_int
# nanosleep(p1, p2)
nanosleep.argtypes = [POINTER(timespec), POINTER(timespec)]
nanosleep.__doc__ = \
"""int nanosleep(unknown * p1, timespec * p2)
/usr/include/time.h:157"""
DWORD = c_ulong
ULONG = c_ulong
USHORT = c_ushort
SHORT = c_short
UCHAR = c_ubyte
WORD = c_ushort
BYTE = c_ubyte
LPBYTE = POINTER(c_ubyte)
BOOL = c_int
BOOLEAN = c_char
CHAR = c_char
LPBOOL = POINTER(c_int)
PUCHAR = POINTER(c_ubyte)
LPCSTR = STRING
PCHAR = STRING
PVOID = c_void_p
HANDLE = c_void_p
LONG = c_long
INT = c_int
UINT = c_uint
LPSTR = STRING
LPTSTR = STRING
LPDWORD = POINTER(DWORD)
LPWORD = POINTER(WORD)
PULONG = POINTER(ULONG)
LPVOID = PVOID
VOID = None
ULONGLONG = c_ulonglong
# /usr/local/include/WinTypes.h 36
class _OVERLAPPED(Structure):
    pass
_OVERLAPPED._fields_ = [
    # /usr/local/include/WinTypes.h 36
    ('Internal', DWORD),
    ('InternalHigh', DWORD),
    ('Offset', DWORD),
    ('OffsetHigh', DWORD),
    ('hEvent', HANDLE),
]
LPOVERLAPPED = POINTER(_OVERLAPPED)
OVERLAPPED = _OVERLAPPED
# /usr/local/include/WinTypes.h 44
class _SECURITY_ATTRIBUTES(Structure):
    pass
_SECURITY_ATTRIBUTES._fields_ = [
    # /usr/local/include/WinTypes.h 44
    ('nLength', DWORD),
    ('lpSecurityDescriptor', LPVOID),
    ('bInheritHandle', BOOL),
]
LPSECURITY_ATTRIBUTES = POINTER(_SECURITY_ATTRIBUTES)
SECURITY_ATTRIBUTES = _SECURITY_ATTRIBUTES
SYSTEMTIME = timeval
FILETIME = timeval
# /usr/local/include/ftd2xx.h 64
class _EVENT_HANDLE(Structure):
    pass
_EVENT_HANDLE._fields_ = [
    # /usr/local/include/ftd2xx.h 64
    ('eCondVar', pthread_cond_t),
    ('eMutex', pthread_mutex_t),
    ('iVar', c_int),
]
EVENT_HANDLE = _EVENT_HANDLE
FT_HANDLE = POINTER(DWORD)
FT_STATUS = ULONG

# values for unnamed enumeration
PFT_EVENT_HANDLER = CFUNCTYPE(None, DWORD, DWORD)
FT_DEVICE = ULONG

# values for unnamed enumeration
# /usr/local/include/ftd2xx.h 223
FT_Open = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_Open
FT_Open.restype = FT_STATUS
# FT_Open(deviceNumber, pHandle)
FT_Open.argtypes = [c_int, POINTER(FT_HANDLE)]
FT_Open.__doc__ = \
"""FT_STATUS FT_Open(int deviceNumber, FT_HANDLE * pHandle)
/usr/local/include/ftd2xx.h:223"""
# /usr/local/include/ftd2xx.h 230
FT_OpenEx = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_OpenEx
FT_OpenEx.restype = FT_STATUS
# FT_OpenEx(pArg1, Flags, pHandle)
FT_OpenEx.argtypes = [PVOID, DWORD, POINTER(FT_HANDLE)]
FT_OpenEx.__doc__ = \
"""FT_STATUS FT_OpenEx(PVOID pArg1, DWORD Flags, FT_HANDLE * pHandle)
/usr/local/include/ftd2xx.h:230"""
# /usr/local/include/ftd2xx.h 237
FT_ListDevices = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_ListDevices
FT_ListDevices.restype = FT_STATUS
# FT_ListDevices(pArg1, pArg2, Flags)
FT_ListDevices.argtypes = [PVOID, PVOID, DWORD]
FT_ListDevices.__doc__ = \
"""FT_STATUS FT_ListDevices(PVOID pArg1, PVOID pArg2, DWORD Flags)
/usr/local/include/ftd2xx.h:237"""
# /usr/local/include/ftd2xx.h 243
FT_SetVIDPID = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetVIDPID
FT_SetVIDPID.restype = FT_STATUS
# FT_SetVIDPID(dwVID, dwPID)
FT_SetVIDPID.argtypes = [DWORD, DWORD]
FT_SetVIDPID.__doc__ = \
"""FT_STATUS FT_SetVIDPID(DWORD dwVID, DWORD dwPID)
/usr/local/include/ftd2xx.h:243"""
# /usr/local/include/ftd2xx.h 249
FT_GetVIDPID = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetVIDPID
FT_GetVIDPID.restype = FT_STATUS
# FT_GetVIDPID(pdwVID, pdwPID)
FT_GetVIDPID.argtypes = [POINTER(DWORD), POINTER(DWORD)]
FT_GetVIDPID.__doc__ = \
"""FT_STATUS FT_GetVIDPID(DWORD * pdwVID, DWORD * pdwPID)
/usr/local/include/ftd2xx.h:249"""
# /usr/local/include/ftd2xx.h 254
FT_Close = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_Close
FT_Close.restype = FT_STATUS
# FT_Close(ftHandle)
FT_Close.argtypes = [FT_HANDLE]
FT_Close.__doc__ = \
"""FT_STATUS FT_Close(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:254"""
# /usr/local/include/ftd2xx.h 262
FT_Read = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_Read
FT_Read.restype = FT_STATUS
# FT_Read(ftHandle, lpBuffer, nBufferSize, lpBytesReturned)
FT_Read.argtypes = [FT_HANDLE, LPVOID, DWORD, LPDWORD]
FT_Read.__doc__ = \
"""FT_STATUS FT_Read(FT_HANDLE ftHandle, LPVOID lpBuffer, DWORD nBufferSize, LPDWORD lpBytesReturned)
/usr/local/include/ftd2xx.h:262"""
# /usr/local/include/ftd2xx.h 270
FT_Write = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_Write
FT_Write.restype = FT_STATUS
# FT_Write(ftHandle, lpBuffer, nBufferSize, lpBytesWritten)
FT_Write.argtypes = [FT_HANDLE, LPVOID, DWORD, LPDWORD]
FT_Write.__doc__ = \
"""FT_STATUS FT_Write(FT_HANDLE ftHandle, LPVOID lpBuffer, DWORD nBufferSize, LPDWORD lpBytesWritten)
/usr/local/include/ftd2xx.h:270"""
# /usr/local/include/ftd2xx.h 282
FT_IoCtl = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_IoCtl
FT_IoCtl.restype = FT_STATUS
# FT_IoCtl(ftHandle, dwIoControlCode, lpInBuf, nInBufSize, lpOutBuf, nOutBufSize, lpBytesReturned, lpOverlapped)
FT_IoCtl.argtypes = [FT_HANDLE, DWORD, LPVOID, DWORD, LPVOID, DWORD, LPDWORD, LPOVERLAPPED]
FT_IoCtl.__doc__ = \
"""FT_STATUS FT_IoCtl(FT_HANDLE ftHandle, DWORD dwIoControlCode, LPVOID lpInBuf, DWORD nInBufSize, LPVOID lpOutBuf, DWORD nOutBufSize, LPDWORD lpBytesReturned, LPOVERLAPPED lpOverlapped)
/usr/local/include/ftd2xx.h:282"""
# /usr/local/include/ftd2xx.h 288
FT_SetBaudRate = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetBaudRate
FT_SetBaudRate.restype = FT_STATUS
# FT_SetBaudRate(ftHandle, BaudRate)
FT_SetBaudRate.argtypes = [FT_HANDLE, ULONG]
FT_SetBaudRate.__doc__ = \
"""FT_STATUS FT_SetBaudRate(FT_HANDLE ftHandle, ULONG BaudRate)
/usr/local/include/ftd2xx.h:288"""
# /usr/local/include/ftd2xx.h 294
FT_SetDivisor = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetDivisor
FT_SetDivisor.restype = FT_STATUS
# FT_SetDivisor(ftHandle, Divisor)
FT_SetDivisor.argtypes = [FT_HANDLE, USHORT]
FT_SetDivisor.__doc__ = \
"""FT_STATUS FT_SetDivisor(FT_HANDLE ftHandle, USHORT Divisor)
/usr/local/include/ftd2xx.h:294"""
# /usr/local/include/ftd2xx.h 302
FT_SetDataCharacteristics = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetDataCharacteristics
FT_SetDataCharacteristics.restype = FT_STATUS
# FT_SetDataCharacteristics(ftHandle, WordLength, StopBits, Parity)
FT_SetDataCharacteristics.argtypes = [FT_HANDLE, UCHAR, UCHAR, UCHAR]
FT_SetDataCharacteristics.__doc__ = \
"""FT_STATUS FT_SetDataCharacteristics(FT_HANDLE ftHandle, UCHAR WordLength, UCHAR StopBits, UCHAR Parity)
/usr/local/include/ftd2xx.h:302"""
# /usr/local/include/ftd2xx.h 310
FT_SetFlowControl = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetFlowControl
FT_SetFlowControl.restype = FT_STATUS
# FT_SetFlowControl(ftHandle, FlowControl, XonChar, XoffChar)
FT_SetFlowControl.argtypes = [FT_HANDLE, USHORT, UCHAR, UCHAR]
FT_SetFlowControl.__doc__ = \
"""FT_STATUS FT_SetFlowControl(FT_HANDLE ftHandle, USHORT FlowControl, UCHAR XonChar, UCHAR XoffChar)
/usr/local/include/ftd2xx.h:310"""
# /usr/local/include/ftd2xx.h 315
FT_ResetDevice = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_ResetDevice
FT_ResetDevice.restype = FT_STATUS
# FT_ResetDevice(ftHandle)
FT_ResetDevice.argtypes = [FT_HANDLE]
FT_ResetDevice.__doc__ = \
"""FT_STATUS FT_ResetDevice(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:315"""
# /usr/local/include/ftd2xx.h 320
FT_SetDtr = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetDtr
FT_SetDtr.restype = FT_STATUS
# FT_SetDtr(ftHandle)
FT_SetDtr.argtypes = [FT_HANDLE]
FT_SetDtr.__doc__ = \
"""FT_STATUS FT_SetDtr(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:320"""
# /usr/local/include/ftd2xx.h 325
FT_ClrDtr = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_ClrDtr
FT_ClrDtr.restype = FT_STATUS
# FT_ClrDtr(ftHandle)
FT_ClrDtr.argtypes = [FT_HANDLE]
FT_ClrDtr.__doc__ = \
"""FT_STATUS FT_ClrDtr(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:325"""
# /usr/local/include/ftd2xx.h 330
FT_SetRts = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetRts
FT_SetRts.restype = FT_STATUS
# FT_SetRts(ftHandle)
FT_SetRts.argtypes = [FT_HANDLE]
FT_SetRts.__doc__ = \
"""FT_STATUS FT_SetRts(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:330"""
# /usr/local/include/ftd2xx.h 335
FT_ClrRts = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_ClrRts
FT_ClrRts.restype = FT_STATUS
# FT_ClrRts(ftHandle)
FT_ClrRts.argtypes = [FT_HANDLE]
FT_ClrRts.__doc__ = \
"""FT_STATUS FT_ClrRts(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:335"""
# /usr/local/include/ftd2xx.h 341
FT_GetModemStatus = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetModemStatus
FT_GetModemStatus.restype = FT_STATUS
# FT_GetModemStatus(ftHandle, pModemStatus)
FT_GetModemStatus.argtypes = [FT_HANDLE, POINTER(ULONG)]
FT_GetModemStatus.__doc__ = \
"""FT_STATUS FT_GetModemStatus(FT_HANDLE ftHandle, ULONG * pModemStatus)
/usr/local/include/ftd2xx.h:341"""
# /usr/local/include/ftd2xx.h 350
FT_SetChars = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetChars
FT_SetChars.restype = FT_STATUS
# FT_SetChars(ftHandle, EventChar, EventCharEnabled, ErrorChar, ErrorCharEnabled)
FT_SetChars.argtypes = [FT_HANDLE, UCHAR, UCHAR, UCHAR, UCHAR]
FT_SetChars.__doc__ = \
"""FT_STATUS FT_SetChars(FT_HANDLE ftHandle, UCHAR EventChar, UCHAR EventCharEnabled, UCHAR ErrorChar, UCHAR ErrorCharEnabled)
/usr/local/include/ftd2xx.h:350"""
# /usr/local/include/ftd2xx.h 356
FT_Purge = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_Purge
FT_Purge.restype = FT_STATUS
# FT_Purge(ftHandle, Mask)
FT_Purge.argtypes = [FT_HANDLE, ULONG]
FT_Purge.__doc__ = \
"""FT_STATUS FT_Purge(FT_HANDLE ftHandle, ULONG Mask)
/usr/local/include/ftd2xx.h:356"""
# /usr/local/include/ftd2xx.h 363
FT_SetTimeouts = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetTimeouts
FT_SetTimeouts.restype = FT_STATUS
# FT_SetTimeouts(ftHandle, ReadTimeout, WriteTimeout)
FT_SetTimeouts.argtypes = [FT_HANDLE, ULONG, ULONG]
FT_SetTimeouts.__doc__ = \
"""FT_STATUS FT_SetTimeouts(FT_HANDLE ftHandle, ULONG ReadTimeout, ULONG WriteTimeout)
/usr/local/include/ftd2xx.h:363"""
# /usr/local/include/ftd2xx.h 369
FT_GetQueueStatus = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetQueueStatus
FT_GetQueueStatus.restype = FT_STATUS
# FT_GetQueueStatus(ftHandle, dwRxBytes)
FT_GetQueueStatus.argtypes = [FT_HANDLE, POINTER(DWORD)]
FT_GetQueueStatus.__doc__ = \
"""FT_STATUS FT_GetQueueStatus(FT_HANDLE ftHandle, DWORD * dwRxBytes)
/usr/local/include/ftd2xx.h:369"""
# /usr/local/include/ftd2xx.h 376
FT_SetEventNotification = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetEventNotification
FT_SetEventNotification.restype = FT_STATUS
# FT_SetEventNotification(ftHandle, Mask, Param)
FT_SetEventNotification.argtypes = [FT_HANDLE, DWORD, PVOID]
FT_SetEventNotification.__doc__ = \
"""FT_STATUS FT_SetEventNotification(FT_HANDLE ftHandle, DWORD Mask, PVOID Param)
/usr/local/include/ftd2xx.h:376"""
# /usr/local/include/ftd2xx.h 384
FT_GetStatus = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetStatus
FT_GetStatus.restype = FT_STATUS
# FT_GetStatus(ftHandle, dwRxBytes, dwTxBytes, dwEventDWord)
FT_GetStatus.argtypes = [FT_HANDLE, POINTER(DWORD), POINTER(DWORD), POINTER(DWORD)]
FT_GetStatus.__doc__ = \
"""FT_STATUS FT_GetStatus(FT_HANDLE ftHandle, DWORD * dwRxBytes, DWORD * dwTxBytes, DWORD * dwEventDWord)
/usr/local/include/ftd2xx.h:384"""
# /usr/local/include/ftd2xx.h 389
FT_SetBreakOn = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetBreakOn
FT_SetBreakOn.restype = FT_STATUS
# FT_SetBreakOn(ftHandle)
FT_SetBreakOn.argtypes = [FT_HANDLE]
FT_SetBreakOn.__doc__ = \
"""FT_STATUS FT_SetBreakOn(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:389"""
# /usr/local/include/ftd2xx.h 394
FT_SetBreakOff = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetBreakOff
FT_SetBreakOff.restype = FT_STATUS
# FT_SetBreakOff(ftHandle)
FT_SetBreakOff.argtypes = [FT_HANDLE]
FT_SetBreakOff.__doc__ = \
"""FT_STATUS FT_SetBreakOff(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:394"""
# /usr/local/include/ftd2xx.h 400
FT_SetWaitMask = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetWaitMask
FT_SetWaitMask.restype = FT_STATUS
# FT_SetWaitMask(ftHandle, Mask)
FT_SetWaitMask.argtypes = [FT_HANDLE, DWORD]
FT_SetWaitMask.__doc__ = \
"""FT_STATUS FT_SetWaitMask(FT_HANDLE ftHandle, DWORD Mask)
/usr/local/include/ftd2xx.h:400"""
# /usr/local/include/ftd2xx.h 406
FT_WaitOnMask = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_WaitOnMask
FT_WaitOnMask.restype = FT_STATUS
# FT_WaitOnMask(ftHandle, Mask)
FT_WaitOnMask.argtypes = [FT_HANDLE, POINTER(DWORD)]
FT_WaitOnMask.__doc__ = \
"""FT_STATUS FT_WaitOnMask(FT_HANDLE ftHandle, DWORD * Mask)
/usr/local/include/ftd2xx.h:406"""
# /usr/local/include/ftd2xx.h 412
FT_GetEventStatus = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetEventStatus
FT_GetEventStatus.restype = FT_STATUS
# FT_GetEventStatus(ftHandle, dwEventDWord)
FT_GetEventStatus.argtypes = [FT_HANDLE, POINTER(DWORD)]
FT_GetEventStatus.__doc__ = \
"""FT_STATUS FT_GetEventStatus(FT_HANDLE ftHandle, DWORD * dwEventDWord)
/usr/local/include/ftd2xx.h:412"""
# /usr/local/include/ftd2xx.h 419
FT_ReadEE = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_ReadEE
FT_ReadEE.restype = FT_STATUS
# FT_ReadEE(ftHandle, dwWordOffset, lpwValue)
FT_ReadEE.argtypes = [FT_HANDLE, DWORD, LPWORD]
FT_ReadEE.__doc__ = \
"""FT_STATUS FT_ReadEE(FT_HANDLE ftHandle, DWORD dwWordOffset, LPWORD lpwValue)
/usr/local/include/ftd2xx.h:419"""
# /usr/local/include/ftd2xx.h 426
FT_WriteEE = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_WriteEE
FT_WriteEE.restype = FT_STATUS
# FT_WriteEE(ftHandle, dwWordOffset, wValue)
FT_WriteEE.argtypes = [FT_HANDLE, DWORD, WORD]
FT_WriteEE.__doc__ = \
"""FT_STATUS FT_WriteEE(FT_HANDLE ftHandle, DWORD dwWordOffset, WORD wValue)
/usr/local/include/ftd2xx.h:426"""
# /usr/local/include/ftd2xx.h 431
FT_EraseEE = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_EraseEE
FT_EraseEE.restype = FT_STATUS
# FT_EraseEE(ftHandle)
FT_EraseEE.argtypes = [FT_HANDLE]
FT_EraseEE.__doc__ = \
"""FT_STATUS FT_EraseEE(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:431"""
# /usr/local/include/ftd2xx.h 436
class ft_program_data(Structure):
    pass
ft_program_data._fields_ = [
    # /usr/local/include/ftd2xx.h 436
    ('Signature1', DWORD),
    ('Signature2', DWORD),
    ('Version', DWORD),
    ('VendorId', WORD),
    ('ProductId', WORD),
    ('Manufacturer', STRING),
    ('ManufacturerId', STRING),
    ('Description', STRING),
    ('SerialNumber', STRING),
    ('MaxPower', WORD),
    ('PnP', WORD),
    ('SelfPowered', WORD),
    ('RemoteWakeup', WORD),
    ('Rev4', UCHAR),
    ('IsoIn', UCHAR),
    ('IsoOut', UCHAR),
    ('PullDownEnable', UCHAR),
    ('SerNumEnable', UCHAR),
    ('USBVersionEnable', UCHAR),
    ('USBVersion', WORD),
    ('Rev5', UCHAR),
    ('IsoInA', UCHAR),
    ('IsoInB', UCHAR),
    ('IsoOutA', UCHAR),
    ('IsoOutB', UCHAR),
    ('PullDownEnable5', UCHAR),
    ('SerNumEnable5', UCHAR),
    ('USBVersionEnable5', UCHAR),
    ('USBVersion5', WORD),
    ('AIsHighCurrent', UCHAR),
    ('BIsHighCurrent', UCHAR),
    ('IFAIsFifo', UCHAR),
    ('IFAIsFifoTar', UCHAR),
    ('IFAIsFastSer', UCHAR),
    ('AIsVCP', UCHAR),
    ('IFBIsFifo', UCHAR),
    ('IFBIsFifoTar', UCHAR),
    ('IFBIsFastSer', UCHAR),
    ('BIsVCP', UCHAR),
    ('UseExtOsc', UCHAR),
    ('HighDriveIOs', UCHAR),
    ('EndpointSize', UCHAR),
    ('PullDownEnableR', UCHAR),
    ('SerNumEnableR', UCHAR),
    ('InvertTXD', UCHAR),
    ('InvertRXD', UCHAR),
    ('InvertRTS', UCHAR),
    ('InvertCTS', UCHAR),
    ('InvertDTR', UCHAR),
    ('InvertDSR', UCHAR),
    ('InvertDCD', UCHAR),
    ('InvertRI', UCHAR),
    ('Cbus0', UCHAR),
    ('Cbus1', UCHAR),
    ('Cbus2', UCHAR),
    ('Cbus3', UCHAR),
    ('Cbus4', UCHAR),
    ('RIsVCP', UCHAR),
]
FT_PROGRAM_DATA = ft_program_data
PFT_PROGRAM_DATA = POINTER(ft_program_data)
# /usr/local/include/ftd2xx.h 521
FT_EE_Program = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_EE_Program
FT_EE_Program.restype = FT_STATUS
# FT_EE_Program(ftHandle, pData)
FT_EE_Program.argtypes = [FT_HANDLE, PFT_PROGRAM_DATA]
FT_EE_Program.__doc__ = \
"""FT_STATUS FT_EE_Program(FT_HANDLE ftHandle, PFT_PROGRAM_DATA pData)
/usr/local/include/ftd2xx.h:521"""
# /usr/local/include/ftd2xx.h 531
FT_EE_ProgramEx = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_EE_ProgramEx
FT_EE_ProgramEx.restype = FT_STATUS
# FT_EE_ProgramEx(ftHandle, lpData, Manufacturer, ManufacturerId, Description, SerialNumber)
FT_EE_ProgramEx.argtypes = [FT_HANDLE, PFT_PROGRAM_DATA, STRING, STRING, STRING, STRING]
FT_EE_ProgramEx.__doc__ = \
"""FT_STATUS FT_EE_ProgramEx(FT_HANDLE ftHandle, PFT_PROGRAM_DATA lpData, char * Manufacturer, char * ManufacturerId, char * Description, char * SerialNumber)
/usr/local/include/ftd2xx.h:531"""
# /usr/local/include/ftd2xx.h 537
FT_EE_Read = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_EE_Read
FT_EE_Read.restype = FT_STATUS
# FT_EE_Read(ftHandle, pData)
FT_EE_Read.argtypes = [FT_HANDLE, PFT_PROGRAM_DATA]
FT_EE_Read.__doc__ = \
"""FT_STATUS FT_EE_Read(FT_HANDLE ftHandle, PFT_PROGRAM_DATA pData)
/usr/local/include/ftd2xx.h:537"""
# /usr/local/include/ftd2xx.h 547
FT_EE_ReadEx = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_EE_ReadEx
FT_EE_ReadEx.restype = FT_STATUS
# FT_EE_ReadEx(ftHandle, lpData, Manufacturer, ManufacturerId, Description, SerialNumber)
FT_EE_ReadEx.argtypes = [FT_HANDLE, PFT_PROGRAM_DATA, STRING, STRING, STRING, STRING]
FT_EE_ReadEx.__doc__ = \
"""FT_STATUS FT_EE_ReadEx(FT_HANDLE ftHandle, PFT_PROGRAM_DATA lpData, char * Manufacturer, char * ManufacturerId, char * Description, char * SerialNumber)
/usr/local/include/ftd2xx.h:547"""
# /usr/local/include/ftd2xx.h 553
FT_EE_UASize = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_EE_UASize
FT_EE_UASize.restype = FT_STATUS
# FT_EE_UASize(ftHandle, lpdwSize)
FT_EE_UASize.argtypes = [FT_HANDLE, LPDWORD]
FT_EE_UASize.__doc__ = \
"""FT_STATUS FT_EE_UASize(FT_HANDLE ftHandle, LPDWORD lpdwSize)
/usr/local/include/ftd2xx.h:553"""
# /usr/local/include/ftd2xx.h 560
FT_EE_UAWrite = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_EE_UAWrite
FT_EE_UAWrite.restype = FT_STATUS
# FT_EE_UAWrite(ftHandle, pucData, dwDataLen)
FT_EE_UAWrite.argtypes = [FT_HANDLE, PUCHAR, DWORD]
FT_EE_UAWrite.__doc__ = \
"""FT_STATUS FT_EE_UAWrite(FT_HANDLE ftHandle, PUCHAR pucData, DWORD dwDataLen)
/usr/local/include/ftd2xx.h:560"""
# /usr/local/include/ftd2xx.h 568
FT_EE_UARead = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_EE_UARead
FT_EE_UARead.restype = FT_STATUS
# FT_EE_UARead(ftHandle, pucData, dwDataLen, lpdwBytesRead)
FT_EE_UARead.argtypes = [FT_HANDLE, PUCHAR, DWORD, LPDWORD]
FT_EE_UARead.__doc__ = \
"""FT_STATUS FT_EE_UARead(FT_HANDLE ftHandle, PUCHAR pucData, DWORD dwDataLen, LPDWORD lpdwBytesRead)
/usr/local/include/ftd2xx.h:568"""
# /usr/local/include/ftd2xx.h 574
FT_SetLatencyTimer = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetLatencyTimer
FT_SetLatencyTimer.restype = FT_STATUS
# FT_SetLatencyTimer(ftHandle, ucLatency)
FT_SetLatencyTimer.argtypes = [FT_HANDLE, UCHAR]
FT_SetLatencyTimer.__doc__ = \
"""FT_STATUS FT_SetLatencyTimer(FT_HANDLE ftHandle, UCHAR ucLatency)
/usr/local/include/ftd2xx.h:574"""
# /usr/local/include/ftd2xx.h 580
FT_GetLatencyTimer = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetLatencyTimer
FT_GetLatencyTimer.restype = FT_STATUS
# FT_GetLatencyTimer(ftHandle, pucLatency)
FT_GetLatencyTimer.argtypes = [FT_HANDLE, PUCHAR]
FT_GetLatencyTimer.__doc__ = \
"""FT_STATUS FT_GetLatencyTimer(FT_HANDLE ftHandle, PUCHAR pucLatency)
/usr/local/include/ftd2xx.h:580"""
# /usr/local/include/ftd2xx.h 587
FT_SetBitMode = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetBitMode
FT_SetBitMode.restype = FT_STATUS
# FT_SetBitMode(ftHandle, ucMask, ucEnable)
FT_SetBitMode.argtypes = [FT_HANDLE, UCHAR, UCHAR]
FT_SetBitMode.__doc__ = \
"""FT_STATUS FT_SetBitMode(FT_HANDLE ftHandle, UCHAR ucMask, UCHAR ucEnable)
/usr/local/include/ftd2xx.h:587"""
# /usr/local/include/ftd2xx.h 593
FT_GetBitMode = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetBitMode
FT_GetBitMode.restype = FT_STATUS
# FT_GetBitMode(ftHandle, pucMode)
FT_GetBitMode.argtypes = [FT_HANDLE, PUCHAR]
FT_GetBitMode.__doc__ = \
"""FT_STATUS FT_GetBitMode(FT_HANDLE ftHandle, PUCHAR pucMode)
/usr/local/include/ftd2xx.h:593"""
# /usr/local/include/ftd2xx.h 600
FT_SetUSBParameters = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetUSBParameters
FT_SetUSBParameters.restype = FT_STATUS
# FT_SetUSBParameters(ftHandle, ulInTransferSize, ulOutTransferSize)
FT_SetUSBParameters.argtypes = [FT_HANDLE, ULONG, ULONG]
FT_SetUSBParameters.__doc__ = \
"""FT_STATUS FT_SetUSBParameters(FT_HANDLE ftHandle, ULONG ulInTransferSize, ULONG ulOutTransferSize)
/usr/local/include/ftd2xx.h:600"""
# /usr/local/include/ftd2xx.h 610
FT_GetDeviceInfo = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetDeviceInfo
FT_GetDeviceInfo.restype = FT_STATUS
# FT_GetDeviceInfo(ftHandle, lpftDevice, lpdwID, SerialNumber, Description, Dummy)
FT_GetDeviceInfo.argtypes = [FT_HANDLE, POINTER(FT_DEVICE), LPDWORD, PCHAR, PCHAR, LPVOID]
FT_GetDeviceInfo.__doc__ = \
"""FT_STATUS FT_GetDeviceInfo(FT_HANDLE ftHandle, FT_DEVICE * lpftDevice, LPDWORD lpdwID, PCHAR SerialNumber, PCHAR Description, LPVOID Dummy)
/usr/local/include/ftd2xx.h:610"""
# /usr/local/include/ftd2xx.h 615
FT_StopInTask = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_StopInTask
FT_StopInTask.restype = FT_STATUS
# FT_StopInTask(ftHandle)
FT_StopInTask.argtypes = [FT_HANDLE]
FT_StopInTask.__doc__ = \
"""FT_STATUS FT_StopInTask(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:615"""
# /usr/local/include/ftd2xx.h 620
FT_RestartInTask = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_RestartInTask
FT_RestartInTask.restype = FT_STATUS
# FT_RestartInTask(ftHandle)
FT_RestartInTask.argtypes = [FT_HANDLE]
FT_RestartInTask.__doc__ = \
"""FT_STATUS FT_RestartInTask(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:620"""
# /usr/local/include/ftd2xx.h 626
FT_SetResetPipeRetryCount = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_SetResetPipeRetryCount
FT_SetResetPipeRetryCount.restype = FT_STATUS
# FT_SetResetPipeRetryCount(ftHandle, dwCount)
FT_SetResetPipeRetryCount.argtypes = [FT_HANDLE, DWORD]
FT_SetResetPipeRetryCount.__doc__ = \
"""FT_STATUS FT_SetResetPipeRetryCount(FT_HANDLE ftHandle, DWORD dwCount)
/usr/local/include/ftd2xx.h:626"""
# /usr/local/include/ftd2xx.h 631
FT_ResetPort = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_ResetPort
FT_ResetPort.restype = FT_STATUS
# FT_ResetPort(ftHandle)
FT_ResetPort.argtypes = [FT_HANDLE]
FT_ResetPort.__doc__ = \
"""FT_STATUS FT_ResetPort(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:631"""
# /usr/local/include/ftd2xx.h 647
FT_W32_CreateFile = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_CreateFile
FT_W32_CreateFile.restype = FT_HANDLE
# FT_W32_CreateFile(lpszName, dwAccess, dwShareMode, lpSecurityAttributes, dwCreate, dwAttrsAndFlags, hTemplate)
FT_W32_CreateFile.argtypes = [LPCSTR, DWORD, DWORD, LPSECURITY_ATTRIBUTES, DWORD, DWORD, HANDLE]
FT_W32_CreateFile.__doc__ = \
"""FT_HANDLE FT_W32_CreateFile(LPCSTR lpszName, DWORD dwAccess, DWORD dwShareMode, LPSECURITY_ATTRIBUTES lpSecurityAttributes, DWORD dwCreate, DWORD dwAttrsAndFlags, HANDLE hTemplate)
/usr/local/include/ftd2xx.h:647"""
# /usr/local/include/ftd2xx.h 652
FT_W32_CloseHandle = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_CloseHandle
FT_W32_CloseHandle.restype = BOOL
# FT_W32_CloseHandle(ftHandle)
FT_W32_CloseHandle.argtypes = [FT_HANDLE]
FT_W32_CloseHandle.__doc__ = \
"""BOOL FT_W32_CloseHandle(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:652"""
# /usr/local/include/ftd2xx.h 661
FT_W32_ReadFile = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_ReadFile
FT_W32_ReadFile.restype = BOOL
# FT_W32_ReadFile(ftHandle, lpBuffer, nBufferSize, lpBytesReturned, lpOverlapped)
FT_W32_ReadFile.argtypes = [FT_HANDLE, LPVOID, DWORD, LPDWORD, LPOVERLAPPED]
FT_W32_ReadFile.__doc__ = \
"""BOOL FT_W32_ReadFile(FT_HANDLE ftHandle, LPVOID lpBuffer, DWORD nBufferSize, LPDWORD lpBytesReturned, LPOVERLAPPED lpOverlapped)
/usr/local/include/ftd2xx.h:661"""
# /usr/local/include/ftd2xx.h 670
FT_W32_WriteFile = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_WriteFile
FT_W32_WriteFile.restype = BOOL
# FT_W32_WriteFile(ftHandle, lpBuffer, nBufferSize, lpBytesWritten, lpOverlapped)
FT_W32_WriteFile.argtypes = [FT_HANDLE, LPVOID, DWORD, LPDWORD, LPOVERLAPPED]
FT_W32_WriteFile.__doc__ = \
"""BOOL FT_W32_WriteFile(FT_HANDLE ftHandle, LPVOID lpBuffer, DWORD nBufferSize, LPDWORD lpBytesWritten, LPOVERLAPPED lpOverlapped)
/usr/local/include/ftd2xx.h:670"""
# /usr/local/include/ftd2xx.h 675
FT_W32_GetLastError = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_GetLastError
FT_W32_GetLastError.restype = DWORD
# FT_W32_GetLastError(ftHandle)
FT_W32_GetLastError.argtypes = [FT_HANDLE]
FT_W32_GetLastError.__doc__ = \
"""DWORD FT_W32_GetLastError(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:675"""
# /usr/local/include/ftd2xx.h 683
FT_W32_GetOverlappedResult = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_GetOverlappedResult
FT_W32_GetOverlappedResult.restype = BOOL
# FT_W32_GetOverlappedResult(ftHandle, lpOverlapped, lpdwBytesTransferred, bWait)
FT_W32_GetOverlappedResult.argtypes = [FT_HANDLE, LPOVERLAPPED, LPDWORD, BOOL]
FT_W32_GetOverlappedResult.__doc__ = \
"""BOOL FT_W32_GetOverlappedResult(FT_HANDLE ftHandle, LPOVERLAPPED lpOverlapped, LPDWORD lpdwBytesTransferred, BOOL bWait)
/usr/local/include/ftd2xx.h:683"""
# /usr/local/include/ftd2xx.h 688
FT_W32_CancelIo = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_CancelIo
FT_W32_CancelIo.restype = BOOL
# FT_W32_CancelIo(ftHandle)
FT_W32_CancelIo.argtypes = [FT_HANDLE]
FT_W32_CancelIo.__doc__ = \
"""BOOL FT_W32_CancelIo(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:688"""
# /usr/local/include/ftd2xx.h 694
class _FTCOMSTAT(Structure):
    pass
_FTCOMSTAT._fields_ = [
    # /usr/local/include/ftd2xx.h 694
    ('fCtsHold', DWORD, 1),
    ('fDsrHold', DWORD, 1),
    ('fRlsdHold', DWORD, 1),
    ('fXoffHold', DWORD, 1),
    ('fXoffSent', DWORD, 1),
    ('fEof', DWORD, 1),
    ('fTxim', DWORD, 1),
    ('fReserved', DWORD, 25),
    ('cbInQue', DWORD),
    ('cbOutQue', DWORD),
]
LPFTCOMSTAT = POINTER(_FTCOMSTAT)
FTCOMSTAT = _FTCOMSTAT
# /usr/local/include/ftd2xx.h 707
class _FTDCB(Structure):
    pass
_FTDCB._fields_ = [
    # /usr/local/include/ftd2xx.h 707
    ('DCBlength', DWORD),
    ('BaudRate', DWORD),
    ('fBinary', DWORD, 1),
    ('fParity', DWORD, 1),
    ('fOutxCtsFlow', DWORD, 1),
    ('fOutxDsrFlow', DWORD, 1),
    ('fDtrControl', DWORD, 2),
    ('fDsrSensitivity', DWORD, 1),
    ('fTXContinueOnXoff', DWORD, 1),
    ('fOutX', DWORD, 1),
    ('fInX', DWORD, 1),
    ('fErrorChar', DWORD, 1),
    ('fNull', DWORD, 1),
    ('fRtsControl', DWORD, 2),
    ('fAbortOnError', DWORD, 1),
    ('fDummy2', DWORD, 17),
    ('wReserved', WORD),
    ('XonLim', WORD),
    ('XoffLim', WORD),
    ('ByteSize', BYTE),
    ('Parity', BYTE),
    ('StopBits', BYTE),
    ('XonChar', c_char),
    ('XoffChar', c_char),
    ('ErrorChar', c_char),
    ('EofChar', c_char),
    ('EvtChar', c_char),
    ('wReserved1', WORD),
]
FTDCB = _FTDCB
LPFTDCB = POINTER(_FTDCB)
# /usr/local/include/ftd2xx.h 738
class _FTTIMEOUTS(Structure):
    pass
_FTTIMEOUTS._fields_ = [
    # /usr/local/include/ftd2xx.h 738
    ('ReadIntervalTimeout', DWORD),
    ('ReadTotalTimeoutMultiplier', DWORD),
    ('ReadTotalTimeoutConstant', DWORD),
    ('WriteTotalTimeoutMultiplier', DWORD),
    ('WriteTotalTimeoutConstant', DWORD),
]
FTTIMEOUTS = _FTTIMEOUTS
LPFTTIMEOUTS = POINTER(_FTTIMEOUTS)
# /usr/local/include/ftd2xx.h 750
FT_W32_ClearCommBreak = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_ClearCommBreak
FT_W32_ClearCommBreak.restype = BOOL
# FT_W32_ClearCommBreak(ftHandle)
FT_W32_ClearCommBreak.argtypes = [FT_HANDLE]
FT_W32_ClearCommBreak.__doc__ = \
"""BOOL FT_W32_ClearCommBreak(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:750"""
# /usr/local/include/ftd2xx.h 757
FT_W32_ClearCommError = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_ClearCommError
FT_W32_ClearCommError.restype = BOOL
# FT_W32_ClearCommError(ftHandle, lpdwErrors, lpftComstat)
FT_W32_ClearCommError.argtypes = [FT_HANDLE, LPDWORD, LPFTCOMSTAT]
FT_W32_ClearCommError.__doc__ = \
"""BOOL FT_W32_ClearCommError(FT_HANDLE ftHandle, LPDWORD lpdwErrors, LPFTCOMSTAT lpftComstat)
/usr/local/include/ftd2xx.h:757"""
# /usr/local/include/ftd2xx.h 763
FT_W32_EscapeCommFunction = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_EscapeCommFunction
FT_W32_EscapeCommFunction.restype = BOOL
# FT_W32_EscapeCommFunction(ftHandle, dwFunc)
FT_W32_EscapeCommFunction.argtypes = [FT_HANDLE, DWORD]
FT_W32_EscapeCommFunction.__doc__ = \
"""BOOL FT_W32_EscapeCommFunction(FT_HANDLE ftHandle, DWORD dwFunc)
/usr/local/include/ftd2xx.h:763"""
# /usr/local/include/ftd2xx.h 769
FT_W32_GetCommModemStatus = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_GetCommModemStatus
FT_W32_GetCommModemStatus.restype = BOOL
# FT_W32_GetCommModemStatus(ftHandle, lpdwModemStatus)
FT_W32_GetCommModemStatus.argtypes = [FT_HANDLE, LPDWORD]
FT_W32_GetCommModemStatus.__doc__ = \
"""BOOL FT_W32_GetCommModemStatus(FT_HANDLE ftHandle, LPDWORD lpdwModemStatus)
/usr/local/include/ftd2xx.h:769"""
# /usr/local/include/ftd2xx.h 775
FT_W32_GetCommState = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_GetCommState
FT_W32_GetCommState.restype = BOOL
# FT_W32_GetCommState(ftHandle, lpftDcb)
FT_W32_GetCommState.argtypes = [FT_HANDLE, LPFTDCB]
FT_W32_GetCommState.__doc__ = \
"""BOOL FT_W32_GetCommState(FT_HANDLE ftHandle, LPFTDCB lpftDcb)
/usr/local/include/ftd2xx.h:775"""
# /usr/local/include/ftd2xx.h 781
FT_W32_GetCommTimeouts = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_GetCommTimeouts
FT_W32_GetCommTimeouts.restype = BOOL
# FT_W32_GetCommTimeouts(ftHandle, pTimeouts)
FT_W32_GetCommTimeouts.argtypes = [FT_HANDLE, POINTER(FTTIMEOUTS)]
FT_W32_GetCommTimeouts.__doc__ = \
"""BOOL FT_W32_GetCommTimeouts(FT_HANDLE ftHandle, FTTIMEOUTS * pTimeouts)
/usr/local/include/ftd2xx.h:781"""
# /usr/local/include/ftd2xx.h 787
FT_W32_PurgeComm = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_PurgeComm
FT_W32_PurgeComm.restype = BOOL
# FT_W32_PurgeComm(ftHandle, dwMask)
FT_W32_PurgeComm.argtypes = [FT_HANDLE, DWORD]
FT_W32_PurgeComm.__doc__ = \
"""BOOL FT_W32_PurgeComm(FT_HANDLE ftHandle, DWORD dwMask)
/usr/local/include/ftd2xx.h:787"""
# /usr/local/include/ftd2xx.h 792
FT_W32_SetCommBreak = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_SetCommBreak
FT_W32_SetCommBreak.restype = BOOL
# FT_W32_SetCommBreak(ftHandle)
FT_W32_SetCommBreak.argtypes = [FT_HANDLE]
FT_W32_SetCommBreak.__doc__ = \
"""BOOL FT_W32_SetCommBreak(FT_HANDLE ftHandle)
/usr/local/include/ftd2xx.h:792"""
# /usr/local/include/ftd2xx.h 798
FT_W32_SetCommMask = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_SetCommMask
FT_W32_SetCommMask.restype = BOOL
# FT_W32_SetCommMask(ftHandle, ulEventMask)
FT_W32_SetCommMask.argtypes = [FT_HANDLE, ULONG]
FT_W32_SetCommMask.__doc__ = \
"""BOOL FT_W32_SetCommMask(FT_HANDLE ftHandle, ULONG ulEventMask)
/usr/local/include/ftd2xx.h:798"""
# /usr/local/include/ftd2xx.h 804
FT_W32_SetCommState = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_SetCommState
FT_W32_SetCommState.restype = BOOL
# FT_W32_SetCommState(ftHandle, lpftDcb)
FT_W32_SetCommState.argtypes = [FT_HANDLE, LPFTDCB]
FT_W32_SetCommState.__doc__ = \
"""BOOL FT_W32_SetCommState(FT_HANDLE ftHandle, LPFTDCB lpftDcb)
/usr/local/include/ftd2xx.h:804"""
# /usr/local/include/ftd2xx.h 810
FT_W32_SetCommTimeouts = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_SetCommTimeouts
FT_W32_SetCommTimeouts.restype = BOOL
# FT_W32_SetCommTimeouts(ftHandle, pTimeouts)
FT_W32_SetCommTimeouts.argtypes = [FT_HANDLE, POINTER(FTTIMEOUTS)]
FT_W32_SetCommTimeouts.__doc__ = \
"""BOOL FT_W32_SetCommTimeouts(FT_HANDLE ftHandle, FTTIMEOUTS * pTimeouts)
/usr/local/include/ftd2xx.h:810"""
# /usr/local/include/ftd2xx.h 817
FT_W32_SetupComm = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_SetupComm
FT_W32_SetupComm.restype = BOOL
# FT_W32_SetupComm(ftHandle, dwReadBufferSize, dwWriteBufferSize)
FT_W32_SetupComm.argtypes = [FT_HANDLE, DWORD, DWORD]
FT_W32_SetupComm.__doc__ = \
"""BOOL FT_W32_SetupComm(FT_HANDLE ftHandle, DWORD dwReadBufferSize, DWORD dwWriteBufferSize)
/usr/local/include/ftd2xx.h:817"""
# /usr/local/include/ftd2xx.h 824
FT_W32_WaitCommEvent = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_W32_WaitCommEvent
FT_W32_WaitCommEvent.restype = BOOL
# FT_W32_WaitCommEvent(ftHandle, pulEvent, lpOverlapped)
FT_W32_WaitCommEvent.argtypes = [FT_HANDLE, PULONG, LPOVERLAPPED]
FT_W32_WaitCommEvent.__doc__ = \
"""BOOL FT_W32_WaitCommEvent(FT_HANDLE ftHandle, PULONG pulEvent, LPOVERLAPPED lpOverlapped)
/usr/local/include/ftd2xx.h:824"""
# /usr/local/include/ftd2xx.h 830
class _ft_device_list_info_node(Structure):
    pass
_ft_device_list_info_node._fields_ = [
    # /usr/local/include/ftd2xx.h 830
    ('Flags', ULONG),
    ('Type', ULONG),
    ('ID', ULONG),
    ('LocId', DWORD),
    ('SerialNumber', c_char * 16),
    ('Description', c_char * 64),
    ('ftHandle', FT_HANDLE),
]
FT_DEVICE_LIST_INFO_NODE = _ft_device_list_info_node
# /usr/local/include/ftd2xx.h 843
FT_CreateDeviceInfoList = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_CreateDeviceInfoList
FT_CreateDeviceInfoList.restype = FT_STATUS
# FT_CreateDeviceInfoList(lpdwNumDevs)
FT_CreateDeviceInfoList.argtypes = [LPDWORD]
FT_CreateDeviceInfoList.__doc__ = \
"""FT_STATUS FT_CreateDeviceInfoList(LPDWORD lpdwNumDevs)
/usr/local/include/ftd2xx.h:843"""
# /usr/local/include/ftd2xx.h 849
FT_GetDeviceInfoList = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetDeviceInfoList
FT_GetDeviceInfoList.restype = FT_STATUS
# FT_GetDeviceInfoList(pDest, lpdwNumDevs)
FT_GetDeviceInfoList.argtypes = [POINTER(FT_DEVICE_LIST_INFO_NODE), LPDWORD]
FT_GetDeviceInfoList.__doc__ = \
"""FT_STATUS FT_GetDeviceInfoList(FT_DEVICE_LIST_INFO_NODE * pDest, LPDWORD lpdwNumDevs)
/usr/local/include/ftd2xx.h:849"""
# /usr/local/include/ftd2xx.h 861
FT_GetDeviceInfoDetail = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetDeviceInfoDetail
FT_GetDeviceInfoDetail.restype = FT_STATUS
# FT_GetDeviceInfoDetail(dwIndex, lpdwFlags, lpdwType, lpdwID, lpdwLocId, lpSerialNumber, lpDescription, pftHandle)
FT_GetDeviceInfoDetail.argtypes = [DWORD, LPDWORD, LPDWORD, LPDWORD, LPDWORD, LPVOID, LPVOID, POINTER(FT_HANDLE)]
FT_GetDeviceInfoDetail.__doc__ = \
"""FT_STATUS FT_GetDeviceInfoDetail(DWORD dwIndex, LPDWORD lpdwFlags, LPDWORD lpdwType, LPDWORD lpdwID, LPDWORD lpdwLocId, LPVOID lpSerialNumber, LPVOID lpDescription, FT_HANDLE * pftHandle)
/usr/local/include/ftd2xx.h:861"""
# /usr/local/include/ftd2xx.h 867
FT_GetDriverVersion = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetDriverVersion
FT_GetDriverVersion.restype = FT_STATUS
# FT_GetDriverVersion(ftHandle, lpdwVersion)
FT_GetDriverVersion.argtypes = [FT_HANDLE, LPDWORD]
FT_GetDriverVersion.__doc__ = \
"""FT_STATUS FT_GetDriverVersion(FT_HANDLE ftHandle, LPDWORD lpdwVersion)
/usr/local/include/ftd2xx.h:867"""
# /usr/local/include/ftd2xx.h 872
FT_GetLibraryVersion = _libraries['/usr/local/lib/libftd2xx.dylib'].FT_GetLibraryVersion
FT_GetLibraryVersion.restype = FT_STATUS
# FT_GetLibraryVersion(lpdwVersion)
FT_GetLibraryVersion.argtypes = [LPDWORD]
FT_GetLibraryVersion.__doc__ = \
"""FT_STATUS FT_GetLibraryVersion(LPDWORD lpdwVersion)
/usr/local/include/ftd2xx.h:872"""
__mbstate_t._pack_ = 4
__mbstate_t._fields_ = [
    # /usr/include/i386/_types.h 79
    ('__mbstate8', c_char * 128),
    ('_mbstateL', c_longlong),
]
__all__ = ['FT_STATUS', '__int16_t', '__darwin_time_t',
           'pthread_mutex_lock', 'pthread_condattr_getpshared',
           'FT_GetLibraryVersion', 'pthread_getconcurrency',
           'pthread_cond_timedwait_relative_np', 'pthread_testcancel',
           'FT_StopInTask', 'pthread_attr_getscope',
           'FT_GetDeviceInfo', 'strptime', 'mktime', 'tm',
           'localtime', 'FT_ResetPort', 'ctime_r',
           'pthread_rwlockattr_destroy', 'FT_SetDataCharacteristics',
           '__darwin_pthread_t', 'FT_GetModemStatus',
           '__darwin_ssize_t', '__darwin_sigset_t',
           'pthread_is_threaded_np', 'FT_DEVICE_BM',
           'pthread_from_mach_thread_np', 'sched_get_priority_max',
           'pthread_rwlock_t', 'posix2time', 'FT_INVALID_PARAMETER',
           '__uint64_t', 'timespec', '__darwin_va_list', 'clock',
           '__darwin_uuid_t', 'FT_SetRts', 'LPSECURITY_ATTRIBUTES',
           'settimeofday', 'pthread_detach',
           'pthread_attr_setdetachstate', '__darwin_wchar_t',
           'localtime_r', 'pthread_attr_init', 'INT', 'FT_SetDivisor',
           'EVENT_HANDLE', 'pthread_t',
           'pthread_mutexattr_getprotocol',
           'FT_EEPROM_NOT_PROGRAMMED', 'FT_EE_ProgramEx', 'asctime_r',
           'FT_SetDtr', 'FT_SetUSBParameters', 'FT_DEVICE_NOT_OPENED',
           'lutimes', 'pthread_equal', 'FT_INSUFFICIENT_RESOURCES',
           '_opaque_pthread_rwlockattr_t',
           '__darwin_pthread_rwlock_t', 'pthread_yield_np',
           'SECURITY_ATTRIBUTES', '__int8_t',
           'pthread_cond_broadcast', 'gettimeofday',
           '_opaque_pthread_attr_t', 'pthread_sigmask',
           'pthread_rwlockattr_setpshared', 'FT_SetVIDPID',
           'FT_EEPROM_READ_FAILED', 'FT_HANDLE',
           'FT_W32_SetCommBreak', 'pthread_key_t', '__darwin_ino64_t',
           'pthread_mutex_getprioceiling',
           '__darwin_pthread_rwlockattr_t', 'pthread_getspecific',
           '_SECURITY_ATTRIBUTES', 'FT_W32_ClearCommBreak',
           'FT_GetDriverVersion', '_OVERLAPPED',
           'pthread_condattr_setpshared', 'pthread_rwlock_wrlock',
           'pthread_join', 'pthread_rwlockattr_t',
           'pthread_rwlockattr_getpshared',
           'pthread_mutexattr_getprioceiling', 'FT_DEVICE_UNKNOWN',
           '__darwin_off_t', '_opaque_pthread_t',
           'pthread_attr_setschedpolicy', 'FT_OK',
           '__darwin_pthread_condattr_t', '__darwin_id_t',
           'FT_GetLatencyTimer', 'FT_SetEventNotification',
           '__darwin_nl_item', 'pthread_mutexattr_t', 'size_t',
           'FT_INVALID_ARGS', 'LONG', 'PFT_PROGRAM_DATA', 'tzsetwall',
           'pthread_mutexattr_setpshared', 'sched_get_priority_min',
           'FT_GetStatus', 'FT_ClrRts', 'FT_EEPROM_WRITE_FAILED',
           'LPFTTIMEOUTS', 'sigset_t', '__darwin_ptrdiff_t',
           'pthread_get_stacksize_np', 'pthread_attr_getschedparam',
           'pthread_cancel', '__int32_t', 'FT_W32_CancelIo',
           'FILETIME', 'FT_FAILED_TO_WRITE_DEVICE',
           'pthread_attr_setstack', 'pthread_cond_signal',
           'FT_ReadEE', 'clock_t', '__darwin_socklen_t',
           '__darwin_intptr_t', 'pthread_mutexattr_init',
           'FT_W32_GetCommTimeouts', 'FT_W32_GetCommState',
           'pthread_key_delete', 'FT_DEVICE_NOT_OPENED_FOR_ERASE',
           'pthread_attr_setstacksize', 'pthread_setcancelstate',
           'pthread_rwlock_destroy', 'pthread_main_np',
           '__darwin_blkcnt_t', 'OVERLAPPED', '__darwin_ino_t',
           'pthread_attr_t', 'UINT', '__darwin_clock_t',
           'pthread_condattr_init', 'LPWORD', 'FT_Read',
           'pthread_attr_getstacksize', 'CHAR', 'FT_EE_UARead',
           'FT_W32_SetupComm', 'WORD', '__darwin_pthread_mutexattr_t',
           '__darwin_mode_t', 'FT_W32_PurgeComm', '__mbstate_t',
           'HANDLE', '__uint8_t', 'FT_PROGRAM_DATA',
           'FT_EEPROM_NOT_PRESENT', 'FT_W32_WriteFile',
           'pthread_setcanceltype', 'BOOLEAN', 'FT_SetBitMode',
           '__darwin_mbstate_t', 'LPSTR', 'gmtime_r',
           'pthread_cond_t', 'FT_SetLatencyTimer',
           '__darwin_wctype_t', 'pthread_attr_getstackaddr',
           'pthread_get_stackaddr_np', 'pthread_once', 'DWORD',
           'pthread_atfork', 'LPCSTR', 'timeval', 'LPOVERLAPPED',
           'pthread_attr_destroy', 'FT_SetFlowControl',
           'FT_ResetDevice', 'FT_W32_EscapeCommFunction',
           'FT_GetQueueStatus', 'sched_yield', 'FT_WaitOnMask',
           'FT_SetTimeouts', '__darwin_pthread_attr_t',
           '__darwin_wint_t', 'pthread_cond_init',
           'FT_W32_GetOverlappedResult', 'pthread_rwlock_tryrdlock',
           '_opaque_pthread_rwlock_t', 'FT_DEVICE',
           'FT_W32_ClearCommError', 'pthread_attr_getdetachstate',
           'PVOID', '__uint16_t', 'VOID', 'pthread_attr_getstack',
           'timegm', '_opaque_pthread_condattr_t',
           'pthread_setconcurrency', 'FT_OpenEx', '__darwin_gid_t',
           'pthread_mutex_init', 'pthread_mutex_trylock', 'PUCHAR',
           '_FTDCB', 'FT_Close', 'FT_W32_CreateFile', 'FT_Write',
           'FT_W32_GetCommModemStatus', 'pthread_getschedparam',
           'FT_SetBreakOff', 'pthread_cond_wait', 'FT_SetBaudRate',
           'FTTIMEOUTS', 'FT_GetDeviceInfoList', 'futimes', 'SHORT',
           'pthread_attr_getinheritsched', 'pthread_kill',
           'itimerval', 'FT_NOT_SUPPORTED', '__darwin_blksize_t',
           'FT_W32_SetCommMask', 'FT_W32_GetLastError', 'timelocal',
           'pthread_attr_setguardsize', '_opaque_pthread_cond_t',
           'sched_param', '__darwin_ct_rune_t', 'FT_SetChars',
           'strftime', '__darwin_pthread_key_t', 'tzset',
           'time2posix', '__darwin_pthread_handler_rec',
           'pthread_mach_thread_np', 'PFT_EVENT_HANDLER',
           '_opaque_pthread_mutexattr_t', 'FT_EE_ReadEx', 'nanosleep',
           'clockinfo', '__darwin_mach_port_t',
           'FT_DEVICE_LIST_INFO_NODE', 'FT_W32_WaitCommEvent',
           '_opaque_pthread_mutex_t', 'FT_GetEventStatus', 'adjtime',
           '_opaque_pthread_once_t', 'pthread_attr_setschedparam',
           'BYTE', 'pthread_attr_setstackaddr',
           'pthread_mutex_destroy', 'LPDWORD',
           'pthread_mutex_setprioceiling', 'FT_IoCtl',
           'pthread_cond_destroy', 'pthread_rwlock_unlock',
           'pthread_mutexattr_setprotocol', 'LPTSTR',
           'pthread_attr_setscope', 'LPBOOL', 'time_t', 'FT_IO_ERROR',
           'FT_INVALID_HANDLE', 'FT_EEPROM_ERASE_FAILED',
           '__darwin_useconds_t', 'FT_GetVIDPID',
           'pthread_rwlock_rdlock', 'FT_W32_SetCommState',
           '__darwin_pthread_cond_t', 'pthread_attr_getguardsize',
           'setitimer', 'pthread_mutex_t', '__int64_t',
           'ft_program_data', 'FT_EE_UASize', 'suseconds_t',
           'pthread_mutexattr_setprioceiling', 'FT_DEVICE_232R',
           'FTCOMSTAT', 'pthread_condattr_t', 'pthread_once_t',
           'pthread_condattr_destroy', 'pthread_mutexattr_getpshared',
           'pthread_mutexattr_gettype', '__uint32_t', '_FTCOMSTAT',
           'fd_set', 'pthread_attr_getschedpolicy', 'FT_DEVICE_100AX',
           '__darwin_mach_port_name_t', '__darwin_fsfilcnt_t',
           'pthread_rwlockattr_init', 'FT_W32_ReadFile',
           'mach_port_t', 'ctime', '_FTTIMEOUTS', 'FT_SetBreakOn',
           '__darwin_suseconds_t', 'LPVOID', 'FT_Open',
           '__darwin_fsblkcnt_t', 'ULONG', 'FT_DEVICE_2232C',
           'FT_CreateDeviceInfoList', 'FT_DEVICE_AM', 'select',
           'pthread_setspecific', 'asctime', 'FT_EE_Program',
           '__darwin_wctrans_t', 'pthread_exit', 'getitimer',
           'pthread_rwlock_trywrlock', 'UCHAR', 'gmtime', 'LPFTDCB',
           'FT_DEVICE_NOT_FOUND', '__darwin_natural_t',
           '__darwin_size_t', 'FT_GetBitMode', 'LPFTCOMSTAT',
           'PULONG', 'FT_ClrDtr', 'SYSTEMTIME', '__darwin_dev_t',
           '__darwin_pthread_mutex_t', 'LPBYTE', 'FT_ListDevices',
           'pthread_create', '__darwin_rune_t', 'FT_WriteEE',
           '_EVENT_HANDLE', 'pthread_key_create',
           '__darwin_pthread_once_t', 'pthread_mutexattr_destroy',
           'pthread_cond_timedwait', 'FTDCB', '__darwin_uid_t',
           'FT_GetDeviceInfoDetail', 'pthread_setschedparam',
           'FT_W32_CloseHandle', 'pthread_cond_signal_thread_np',
           'pthread_mutex_unlock', '_ft_device_list_info_node',
           'getdate', 'FT_RestartInTask', 'USHORT', 'BOOL',
           'pthread_rwlock_init', 'FT_DEVICE_NOT_OPENED_FOR_WRITE',
           'FT_Purge', 'pthread_mutexattr_settype', 'FT_EE_UAWrite',
           'timezone', '__darwin_pid_t', 'PCHAR', 'ULONGLONG',
           'FT_SetResetPipeRetryCount',
           'pthread_attr_setinheritsched', 'FT_W32_SetCommTimeouts',
           'FT_EraseEE', 'pthread_self', 'FT_INVALID_BAUD_RATE',
           'FT_SetWaitMask', 'utimes', 'pthread_create_suspended_np',
           'difftime', 'time', 'FT_OTHER_ERROR', 'FT_EE_Read']



from __future__ import print_function
from setuptools import setup, find_packages
# import subprocess
# import sys

from distutils.command.build_py import build_py
from distutils.command.build_scripts import build_scripts

import os
import sys
mydir = os.path.dirname(__file__)

if os.path.exists(os.path.join(mydir, '.bzr')):

    from bzrlib.branch import Branch
    branch = Branch.open_containing('.')[0]
    revno = branch.revno()
    revid = branch.get_rev_id(revno)
    rtagdict  = branch.tags.get_reverse_tag_dict()
    if revid in rtagdict:
        version = rtagdict[revid][0]
    else:
        version = 'bzr%s' % revno
    f = open(os.path.join(mydir, 'myversion.txt'), 'w')
    print("version = %s" % version, file=f)
    f.close()
else:
    version = open(os.path.join(mydir, 'myversion.txt'), 'r').read().strip()

with open('README.rst') as f:
    long_description = f.read()

setup(
    name="ftd2xx",
    version=version,
    packages=find_packages(),
    # metadata for upload to PyPI
    author="Satya Mishra",
    author_email="satya.devel@gmail.com",
    description="Python interface to ftd2xx.dll from FTDI using ctypes based on d2xx by Pablo Bleyer",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    license="MIT",
    keywords="ftd2xx d2xx ftdi",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    url='https://github.com/snmishra/ftd2xx',  # project home page, if any
    zip_safe=False,
    test_suite="ftd2xx.tests.t_ftd2xx",
    cmdclass = {'build_py': build_py, 'build_scripts': build_scripts},
    # could also include long_description, download_url, classifiers, etc.
    install_requires=(['future'] +
                      ['pywin32'] if sys.platform == 'win32' else [])
)
